// Code generated by smithy-go-codegen DO NOT EDIT.

package schemas

import (
	smithy "github.com/aws/smithy-go"
	smithyprelude "github.com/aws/smithy-go/prelude"
	smithytraits "github.com/aws/smithy-go/traits"
)

var AllQueryStringTypes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "AllQueryStringTypes",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/AllQueryStringTypesInput",
	Code: 200})

var ConstantAndVariableQueryString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ConstantAndVariableQueryString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/ConstantAndVariableQueryString?foo=bar",
	Code: 200})

var ConstantQueryString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ConstantQueryString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/ConstantQueryString/{hello}?foo=bar&hello",
	Code: 200})

var ContentTypeParameters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ContentTypeParameters",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/ContentTypeParameters",
	Code: 200})

var DatetimeOffsets = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DatetimeOffsets",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/DatetimeOffsets",
	Code: 200})

var DocumentType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentType",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/DocumentType",
	Code: 200})

var DocumentTypeAsMapValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentTypeAsMapValue",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/DocumentTypeAsMapValue",
	Code: 200})

var DocumentTypeAsPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentTypeAsPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/DocumentTypeAsPayload",
	Code: 200})

var DuplexStream = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStream",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/DuplexStream",
	Code: 200})

var DuplexStreamWithDistinctStreams = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamWithDistinctStreams",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/DuplexStreamWithDistinctStreams",
	Code: 200})

var DuplexStreamWithInitialMessages = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamWithInitialMessages",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/DuplexStreamWithInitialMessages",
	Code: 200})

var EmptyInputAndEmptyOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EmptyInputAndEmptyOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EmptyInputAndEmptyOutput",
	Code: 200})

var EndpointOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EndpointOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EndpointOperation",
	Code: 200})

var EndpointWithHostLabelOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EndpointWithHostLabelOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EndpointWithHostLabelOperation",
	Code: 200})

var FractionalSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "FractionalSeconds",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/FractionalSeconds",
	Code: 200})

var GreetingWithErrors = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "GreetingWithErrors",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/GreetingWithErrors",
	Code: 200})

var HostWithPathOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HostWithPathOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HostWithPathOperation",
	Code: 200})

var HttpChecksumRequired = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpChecksumRequired",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/HttpChecksumRequired",
	Code: 200})

var HttpEmptyPrefixHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpEmptyPrefixHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpEmptyPrefixHeaders",
	Code: 200})

var HttpEnumPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpEnumPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/EnumPayload",
	Code: 200})

var HttpPayloadTraits = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadTraits",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/HttpPayloadTraits",
	Code: 200})

var HttpPayloadTraitsWithMediaType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadTraitsWithMediaType",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/HttpPayloadTraitsWithMediaType",
	Code: 200})

var HttpPayloadWithStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadWithStructure",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithStructure",
	Code: 200})

var HttpPayloadWithUnion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadWithUnion",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpPayloadWithUnion",
	Code: 200})

var HttpPrefixHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPrefixHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpPrefixHeaders",
	Code: 200})

var HttpPrefixHeadersInResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPrefixHeadersInResponse",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpPrefixHeadersResponse",
	Code: 200})

var HttpQueryParamsOnlyOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpQueryParamsOnlyOperation",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/http-query-params-only",
	Code: 200})

var HttpRequestWithFloatLabels = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithFloatLabels",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/FloatHttpLabels/{float}/{double}",
	Code: 200})

var HttpRequestWithGreedyLabelInPath = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithGreedyLabelInPath",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpRequestWithGreedyLabelInPath/foo/{foo}/baz/{baz+}",
	Code: 200})

var HttpRequestWithLabels = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithLabels",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpRequestWithLabels/{string}/{short}/{integer}/{long}/{float}/{double}/{boolean}/{timestamp}",
	Code: 200})

var HttpRequestWithLabelsAndTimestampFormat = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithLabelsAndTimestampFormat",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/HttpRequestWithLabelsAndTimestampFormat/{memberEpochSeconds}/{memberHttpDate}/{memberDateTime}/{defaultFormat}/{targetEpochSeconds}/{targetHttpDate}/{targetDateTime}",
	Code: 200})

var HttpRequestWithRegexLiteral = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithRegexLiteral",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/ReDosLiteral/{str}/(a+)+",
	Code: 200})

var HttpResponseCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpResponseCode",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/HttpResponseCode",
	Code: 200})

var HttpStringPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpStringPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StringPayload",
	Code: 200})

var IgnoreQueryParamsInResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "IgnoreQueryParamsInResponse",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/IgnoreQueryParamsInResponse",
	Code: 200})

var InputAndOutputWithHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InputAndOutputWithHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/InputAndOutputWithHeaders",
	Code: 200})

var InputStream = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InputStream",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/InputStream",
	Code: 200})

var InputStreamWithInitialRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InputStreamWithInitialRequest",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/InputStreamWithInitialRequest",
	Code: 200})

var JsonBlobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonBlobs",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/JsonBlobs",
	Code: 200})

var JsonEnums = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonEnums",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/JsonEnums",
	Code: 200})

var JsonIntEnums = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonIntEnums",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/JsonIntEnums",
	Code: 200})

var JsonLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonLists",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/JsonLists",
	Code: 200})

var JsonMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonMaps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/JsonMaps",
	Code: 200})

var JsonTimestamps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonTimestamps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/JsonTimestamps",
	Code: 200})

var JsonUnions = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonUnions",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/JsonUnions",
	Code: 200})

var MalformedAcceptWithBody = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedAcceptWithBody",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedAcceptWithBody",
	Code: 200})

var MalformedAcceptWithGenericString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedAcceptWithGenericString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedAcceptWithGenericString",
	Code: 200})

var MalformedAcceptWithPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedAcceptWithPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedAcceptWithPayload",
	Code: 200})

var MalformedBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedBlob",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedBlob",
	Code: 200})

var MalformedBoolean = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedBoolean",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedBoolean/{booleanInPath}",
	Code: 200})

var MalformedByte = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedByte",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedByte/{byteInPath}",
	Code: 200})

var MalformedContentTypeWithBody = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithBody",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedContentTypeWithBody",
	Code: 200})

var MalformedContentTypeWithGenericString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithGenericString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedContentTypeWithGenericString",
	Code: 200})

var MalformedContentTypeWithoutBody = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithoutBody",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedContentTypeWithoutBody",
	Code: 200})

var MalformedContentTypeWithoutBodyEmptyInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithoutBodyEmptyInput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedContentTypeWithoutBodyEmptyInput",
	Code: 200})

var MalformedContentTypeWithPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedContentTypeWithPayload",
	Code: 200})

var MalformedDouble = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedDouble",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedDouble/{doubleInPath}",
	Code: 200})

var MalformedFloat = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedFloat",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedFloat/{floatInPath}",
	Code: 200})

var MalformedInteger = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedInteger",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedInteger/{integerInPath}",
	Code: 200})

var MalformedList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedList",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedList",
	Code: 200})

var MalformedLong = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedLong",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedLong/{longInPath}",
	Code: 200})

var MalformedMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedMap",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedMap",
	Code: 200})

var MalformedRequestBody = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedRequestBody",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedRequestBody",
	Code: 200})

var MalformedShort = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedShort",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedShort/{shortInPath}",
	Code: 200})

var MalformedString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedString",
	Code: 200})

var MalformedTimestampBodyDateTime = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampBodyDateTime",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampBodyDateTime",
	Code: 200})

var MalformedTimestampBodyDefault = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampBodyDefault",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampBodyDefault",
	Code: 200})

var MalformedTimestampBodyHttpDate = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampBodyHttpDate",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampBodyHttpDate",
	Code: 200})

var MalformedTimestampHeaderDateTime = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampHeaderDateTime",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampHeaderDateTime",
	Code: 200})

var MalformedTimestampHeaderDefault = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampHeaderDefault",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampHeaderDefault",
	Code: 200})

var MalformedTimestampHeaderEpoch = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampHeaderEpoch",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampHeaderEpoch",
	Code: 200})

var MalformedTimestampPathDefault = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampPathDefault",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampPathDefault/{timestamp}",
	Code: 200})

var MalformedTimestampPathEpoch = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampPathEpoch",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampPathEpoch/{timestamp}",
	Code: 200})

var MalformedTimestampPathHttpDate = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampPathHttpDate",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampPathHttpDate/{timestamp}",
	Code: 200})

var MalformedTimestampQueryDefault = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampQueryDefault",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampQueryDefault",
	Code: 200})

var MalformedTimestampQueryEpoch = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampQueryEpoch",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampQueryEpoch",
	Code: 200})

var MalformedTimestampQueryHttpDate = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampQueryHttpDate",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedTimestampQueryHttpDate",
	Code: 200})

var MalformedUnion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedUnion",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/MalformedUnion",
	Code: 200})

var MediaTypeHeader = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MediaTypeHeader",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/MediaTypeHeader",
	Code: 200})

var NoInputAndNoOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NoInputAndNoOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/NoInputAndNoOutput",
	Code: 200})

var NoInputAndOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NoInputAndOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/NoInputAndOutputOutput",
	Code: 200})

var NullAndEmptyHeadersClient = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NullAndEmptyHeadersClient",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/NullAndEmptyHeadersClient",
	Code: 200})

var NullAndEmptyHeadersServer = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NullAndEmptyHeadersServer",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/NullAndEmptyHeadersServer",
	Code: 200})

var OmitsNullSerializesEmptyString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OmitsNullSerializesEmptyString",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/OmitsNullSerializesEmptyString",
	Code: 200})

var OmitsSerializingEmptyLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OmitsSerializingEmptyLists",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/OmitsSerializingEmptyLists",
	Code: 200})

var OperationWithDefaults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OperationWithDefaults",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/OperationWithDefaults",
	Code: 200})

var OperationWithNestedStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OperationWithNestedStructure",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/OperationWithNestedStructure",
	Code: 200})

var OutputStream = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OutputStream",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/OutputStream",
	Code: 200})

var OutputStreamWithInitialResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OutputStreamWithInitialResponse",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/OutputStreamWithInitialResponse",
	Code: 200})

var PostPlayerAction = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PostPlayerAction",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/PostPlayerAction",
	Code: 200})

var PostUnionWithJsonName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PostUnionWithJsonName",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/PostUnionWithJsonName",
	Code: 200})

var PutWithContentEncoding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PutWithContentEncoding",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/requestcompression/putcontentwithencoding",
	Code: 200})

var QueryIdempotencyTokenAutoFill = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryIdempotencyTokenAutoFill",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/QueryIdempotencyTokenAutoFill",
	Code: 200})

var QueryParamsAsStringListMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryParamsAsStringListMap",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StringListMap",
	Code: 200})

var QueryPrecedence = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryPrecedence",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/Precedence",
	Code: 200})

var RecursiveShapes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "RecursiveShapes",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/RecursiveShapes",
	Code: 200})

var ResponseCodeHttpFallback = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ResponseCodeHttpFallback",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/responseCodeHttpFallback",
	Code: 201})

var ResponseCodeRequired = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ResponseCodeRequired",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/responseCodeRequired",
	Code: 200})

var SimpleScalarProperties = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SimpleScalarProperties",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/SimpleScalarProperties",
	Code: 200})

var SparseJsonLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseJsonLists",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "PUT",
	URI:  "/SparseJsonLists",
	Code: 200})

var SparseJsonMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseJsonMaps",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/SparseJsonMaps",
	Code: 200})

var StreamingTraits = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTraits",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StreamingTraits",
	Code: 200})

var StreamingTraitsRequireLength = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTraitsRequireLength",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StreamingTraitsRequireLength",
	Code: 200})

var StreamingTraitsWithMediaType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTraitsWithMediaType",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/StreamingTraitsWithMediaType",
	Code: 200})

var TestBodyStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestBodyStructure",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/body",
	Code: 200})

var TestGetNoInputNoPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestGetNoInputNoPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/no_input_no_payload",
	Code: 200})

var TestGetNoPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestGetNoPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "GET",
	URI:  "/no_payload",
	Code: 200})

var TestPayloadBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestPayloadBlob",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/blob_payload",
	Code: 200})

var TestPayloadStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestPayloadStructure",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/payload",
	Code: 200})

var TestPostNoInputNoPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestPostNoInputNoPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/no_input_no_payload",
	Code: 200})

var TestPostNoPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestPostNoPayload",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/no_payload",
	Code: 200})

var TimestampFormatHeaders = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TimestampFormatHeaders",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/TimestampFormatHeaders",
	Code: 200})

var UnitInputAndOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "UnitInputAndOutput",
}, smithy.ShapeTypeOperation, 0, &smithytraits.HTTP{Method: "POST",
	URI:  "/UnitInputAndOutput",
	Code: 200})

var _RestJson = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "RestJson",
}, smithy.ShapeTypeService, 0)

var RestJson = smithy.NewServiceSchema(_RestJson, "2019-12-16")

var BlobPayloadEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "BlobPayloadEvent",
}, smithy.ShapeTypeStructure, 1)
var BlobPayloadEvent_payload *smithy.Schema

var ClientOptionalDefaults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ClientOptionalDefaults",
}, smithy.ShapeTypeStructure, 1)
var ClientOptionalDefaults_member *smithy.Schema

var ComplexError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ComplexError",
}, smithy.ShapeTypeStructure, 3, &smithytraits.HTTPError{Code: 403})
var ComplexError_Header *smithy.Schema

var ComplexError_TopLevel *smithy.Schema

var ComplexError_Nested *smithy.Schema

var ComplexNestedErrorData = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ComplexNestedErrorData",
}, smithy.ShapeTypeStructure, 1)
var ComplexNestedErrorData_Foo *smithy.Schema

var Defaults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "Defaults",
}, smithy.ShapeTypeStructure, 28)
var Defaults_defaultString *smithy.Schema

var Defaults_defaultBoolean *smithy.Schema

var Defaults_defaultList *smithy.Schema

var Defaults_defaultDocumentMap *smithy.Schema

var Defaults_defaultDocumentString *smithy.Schema

var Defaults_defaultDocumentBoolean *smithy.Schema

var Defaults_defaultDocumentList *smithy.Schema

var Defaults_defaultNullDocument *smithy.Schema

var Defaults_defaultTimestamp *smithy.Schema

var Defaults_defaultBlob *smithy.Schema

var Defaults_defaultByte *smithy.Schema

var Defaults_defaultShort *smithy.Schema

var Defaults_defaultInteger *smithy.Schema

var Defaults_defaultLong *smithy.Schema

var Defaults_defaultFloat *smithy.Schema

var Defaults_defaultDouble *smithy.Schema

var Defaults_defaultMap *smithy.Schema

var Defaults_defaultEnum *smithy.Schema

var Defaults_defaultIntEnum *smithy.Schema

var Defaults_emptyString *smithy.Schema

var Defaults_falseBoolean *smithy.Schema

var Defaults_emptyBlob *smithy.Schema

var Defaults_zeroByte *smithy.Schema

var Defaults_zeroShort *smithy.Schema

var Defaults_zeroInteger *smithy.Schema

var Defaults_zeroLong *smithy.Schema

var Defaults_zeroFloat *smithy.Schema

var Defaults_zeroDouble *smithy.Schema

var _DenseBooleanMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DenseBooleanMap",
}, smithy.ShapeTypeMap, 2)
var _DenseBooleanMap_key *smithy.Schema

var _DenseBooleanMap_value *smithy.Schema

var _DenseNumberMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DenseNumberMap",
}, smithy.ShapeTypeMap, 2)
var _DenseNumberMap_key *smithy.Schema

var _DenseNumberMap_value *smithy.Schema

var _DenseSetMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DenseSetMap",
}, smithy.ShapeTypeMap, 2)
var _DenseSetMap_key *smithy.Schema

var _DenseSetMap_value *smithy.Schema

var _DenseStringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DenseStringMap",
}, smithy.ShapeTypeMap, 2)
var _DenseStringMap_key *smithy.Schema

var _DenseStringMap_value *smithy.Schema

var _DenseStructMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DenseStructMap",
}, smithy.ShapeTypeMap, 2)
var _DenseStructMap_key *smithy.Schema

var _DenseStructMap_value *smithy.Schema

var Dialog = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "Dialog",
}, smithy.ShapeTypeStructure, 3)
var Dialog_language *smithy.Schema

var Dialog_greeting *smithy.Schema

var Dialog_farewell *smithy.Schema

var _DialogList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DialogList",
}, smithy.ShapeTypeList, 1)
var _DialogList_member *smithy.Schema

var _DialogMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DialogMap",
}, smithy.ShapeTypeMap, 2)
var _DialogMap_key *smithy.Schema

var _DialogMap_value *smithy.Schema

var _Document = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "Document",
}, smithy.ShapeTypeDocument, 0)

var _DocumentValuedMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentValuedMap",
}, smithy.ShapeTypeMap, 2)
var _DocumentValuedMap_key *smithy.Schema

var _DocumentValuedMap_value *smithy.Schema

var ErrorEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ErrorEvent",
}, smithy.ShapeTypeStructure, 1)
var ErrorEvent_message *smithy.Schema

var EventStream = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EventStream",
}, smithy.ShapeTypeUnion, 8, &smithytraits.Streaming{})
var EventStream_headers *smithy.Schema

var EventStream_blobPayload *smithy.Schema

var EventStream_stringPayload *smithy.Schema

var EventStream_structurePayload *smithy.Schema

var EventStream_unionPayload *smithy.Schema

var EventStream_headersAndExplicitPayload *smithy.Schema

var EventStream_headersAndImplicitPayload *smithy.Schema

var EventStream_error *smithy.Schema

var Farewell = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "Farewell",
}, smithy.ShapeTypeStructure, 1)
var Farewell_phrase *smithy.Schema

var _FiniteStreamingBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "FiniteStreamingBlob",
}, smithy.ShapeTypeBlob, 0, &smithytraits.Streaming{})

var FooError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "FooError",
}, smithy.ShapeTypeStructure, 0, &smithytraits.HTTPError{Code: 500})

var HeadersAndExplicitPayloadEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HeadersAndExplicitPayloadEvent",
}, smithy.ShapeTypeStructure, 2)
var HeadersAndExplicitPayloadEvent_header *smithy.Schema

var HeadersAndExplicitPayloadEvent_payload *smithy.Schema

var HeadersAndImplicitPayloadEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HeadersAndImplicitPayloadEvent",
}, smithy.ShapeTypeStructure, 2)
var HeadersAndImplicitPayloadEvent_header *smithy.Schema

var HeadersAndImplicitPayloadEvent_payload *smithy.Schema

var HeadersEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HeadersEvent",
}, smithy.ShapeTypeStructure, 8)
var HeadersEvent_booleanHeader *smithy.Schema

var HeadersEvent_byteHeader *smithy.Schema

var HeadersEvent_shortHeader *smithy.Schema

var HeadersEvent_intHeader *smithy.Schema

var HeadersEvent_longHeader *smithy.Schema

var HeadersEvent_blobHeader *smithy.Schema

var HeadersEvent_stringHeader *smithy.Schema

var HeadersEvent_timestampHeader *smithy.Schema

var InvalidGreeting = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InvalidGreeting",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var InvalidGreeting_Message *smithy.Schema

var _JsonHeaderString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonHeaderString",
}, smithy.ShapeTypeString, 0, &smithytraits.MediaType{Type: "application/json"})

var _JsonValue = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonValue",
}, smithy.ShapeTypeString, 0, &smithytraits.MediaType{Type: "application/json"})

var MyUnion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MyUnion",
}, smithy.ShapeTypeUnion, 10)
var MyUnion_stringValue *smithy.Schema

var MyUnion_booleanValue *smithy.Schema

var MyUnion_numberValue *smithy.Schema

var MyUnion_blobValue *smithy.Schema

var MyUnion_timestampValue *smithy.Schema

var MyUnion_enumValue *smithy.Schema

var MyUnion_listValue *smithy.Schema

var MyUnion_mapValue *smithy.Schema

var MyUnion_structureValue *smithy.Schema

var MyUnion_renamedStructureValue *smithy.Schema

var NestedPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NestedPayload",
}, smithy.ShapeTypeStructure, 2)
var NestedPayload_greeting *smithy.Schema

var NestedPayload_name *smithy.Schema

var PayloadConfig = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PayloadConfig",
}, smithy.ShapeTypeStructure, 1)
var PayloadConfig_data *smithy.Schema

var PayloadStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PayloadStructure",
}, smithy.ShapeTypeStructure, 1)
var PayloadStructure_structureMember *smithy.Schema

var PayloadUnion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PayloadUnion",
}, smithy.ShapeTypeUnion, 1)
var PayloadUnion_unionMember *smithy.Schema

var PlayerAction = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PlayerAction",
}, smithy.ShapeTypeUnion, 1)
var PlayerAction_quit *smithy.Schema

var _QueryMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryMap",
}, smithy.ShapeTypeMap, 2)
var _QueryMap_key *smithy.Schema

var _QueryMap_value *smithy.Schema

var RecursiveShapesInputOutputNested1 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "RecursiveShapesInputOutputNested1",
}, smithy.ShapeTypeStructure, 2)
var RecursiveShapesInputOutputNested1_foo *smithy.Schema

var RecursiveShapesInputOutputNested1_nested *smithy.Schema

var RecursiveShapesInputOutputNested2 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "RecursiveShapesInputOutputNested2",
}, smithy.ShapeTypeStructure, 2)
var RecursiveShapesInputOutputNested2_bar *smithy.Schema

var RecursiveShapesInputOutputNested2_recursiveMember *smithy.Schema

var ServiceUnavailableError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ServiceUnavailableError",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 500})
var ServiceUnavailableError_message *smithy.Schema

var _SimpleList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SimpleList",
}, smithy.ShapeTypeList, 1)
var _SimpleList_member *smithy.Schema

var _SimpleMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SimpleMap",
}, smithy.ShapeTypeMap, 2)
var _SimpleMap_key *smithy.Schema

var _SimpleMap_value *smithy.Schema

var SimpleUnion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SimpleUnion",
}, smithy.ShapeTypeUnion, 2)
var SimpleUnion_int *smithy.Schema

var SimpleUnion_string *smithy.Schema

var SingletonEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SingletonEvent",
}, smithy.ShapeTypeStructure, 1)
var SingletonEvent_value *smithy.Schema

var SingletonEventStream = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SingletonEventStream",
}, smithy.ShapeTypeUnion, 1)
var SingletonEventStream_singleton *smithy.Schema

var _SparseBooleanMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseBooleanMap",
}, smithy.ShapeTypeMap, 2)
var _SparseBooleanMap_key *smithy.Schema

var _SparseBooleanMap_value *smithy.Schema

var _SparseNumberMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseNumberMap",
}, smithy.ShapeTypeMap, 2)
var _SparseNumberMap_key *smithy.Schema

var _SparseNumberMap_value *smithy.Schema

var _SparseSetMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseSetMap",
}, smithy.ShapeTypeMap, 2)
var _SparseSetMap_key *smithy.Schema

var _SparseSetMap_value *smithy.Schema

var _SparseStructMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseStructMap",
}, smithy.ShapeTypeMap, 2)
var _SparseStructMap_key *smithy.Schema

var _SparseStructMap_value *smithy.Schema

var _StreamingBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingBlob",
}, smithy.ShapeTypeBlob, 0, &smithytraits.Streaming{})

var _StreamingTextPlainBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTextPlainBlob",
}, smithy.ShapeTypeBlob, 0, &smithytraits.MediaType{Type: "text/plain"},
	&smithytraits.Streaming{})

var StringEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StringEnum",
}, smithy.ShapeTypeEnum, 1)
var StringEnum_V *smithy.Schema

var StringPayloadEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StringPayloadEvent",
}, smithy.ShapeTypeStructure, 1)
var StringPayloadEvent_payload *smithy.Schema

var _StructureList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StructureList",
}, smithy.ShapeTypeList, 1)
var _StructureList_member *smithy.Schema

var StructureListMember = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StructureListMember",
}, smithy.ShapeTypeStructure, 2)
var StructureListMember_a *smithy.Schema

var StructureListMember_b *smithy.Schema

var StructurePayloadEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StructurePayloadEvent",
}, smithy.ShapeTypeStructure, 1)
var StructurePayloadEvent_payload *smithy.Schema

var TestConfig = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestConfig",
}, smithy.ShapeTypeStructure, 1)
var TestConfig_timeout *smithy.Schema

var TestEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestEnum",
}, smithy.ShapeTypeEnum, 3)
var TestEnum_FOO *smithy.Schema

var TestEnum_BAR *smithy.Schema

var TestEnum_BAZ *smithy.Schema

var _TestIntEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestIntEnum",
}, smithy.ShapeTypeIntEnum, 2)
var _TestIntEnum_ONE *smithy.Schema

var _TestIntEnum_TWO *smithy.Schema

var _TestStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestStringList",
}, smithy.ShapeTypeList, 1)
var _TestStringList_member *smithy.Schema

var _TestStringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestStringMap",
}, smithy.ShapeTypeMap, 2)
var _TestStringMap_key *smithy.Schema

var _TestStringMap_value *smithy.Schema

var TopLevel = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TopLevel",
}, smithy.ShapeTypeStructure, 3)
var TopLevel_dialog *smithy.Schema

var TopLevel_dialogList *smithy.Schema

var TopLevel_dialogMap *smithy.Schema

var UnionPayload = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "UnionPayload",
}, smithy.ShapeTypeUnion, 1)
var UnionPayload_greeting *smithy.Schema

var UnionPayloadEvent = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "UnionPayloadEvent",
}, smithy.ShapeTypeStructure, 1)
var UnionPayloadEvent_payload *smithy.Schema

var UnionWithJsonName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "UnionWithJsonName",
}, smithy.ShapeTypeUnion, 3)
var UnionWithJsonName_foo *smithy.Schema

var UnionWithJsonName_bar *smithy.Schema

var UnionWithJsonName_baz *smithy.Schema

var RenamedGreeting = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson.nested",
	Name:      "GreetingStruct",
}, smithy.ShapeTypeStructure, 1)
var RenamedGreeting_salutation *smithy.Schema

var _BooleanList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "BooleanList",
}, smithy.ShapeTypeList, 1)
var _BooleanList_member *smithy.Schema

var _DateTime = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "DateTime",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "date-time"})

var _DoubleList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "DoubleList",
}, smithy.ShapeTypeList, 1)
var _DoubleList_member *smithy.Schema

var _EpochSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "EpochSeconds",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

var FooEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnum",
}, smithy.ShapeTypeEnum, 5)
var FooEnum_FOO *smithy.Schema

var FooEnum_BAZ *smithy.Schema

var FooEnum_BAR *smithy.Schema

var FooEnum_ONE *smithy.Schema

var FooEnum_ZERO *smithy.Schema

var _FooEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumList",
}, smithy.ShapeTypeList, 1)
var _FooEnumList_member *smithy.Schema

var _FooEnumMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumMap",
}, smithy.ShapeTypeMap, 2)
var _FooEnumMap_key *smithy.Schema

var _FooEnumMap_value *smithy.Schema

var _FooEnumSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumSet",
}, smithy.ShapeTypeList, 1)
var _FooEnumSet_member *smithy.Schema

var GreetingStruct = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "GreetingStruct",
}, smithy.ShapeTypeStructure, 1)
var GreetingStruct_hi *smithy.Schema

var _HttpDate = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "HttpDate",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "http-date"})

var _IntegerEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnum",
}, smithy.ShapeTypeIntEnum, 3)
var _IntegerEnum_A *smithy.Schema

var _IntegerEnum_B *smithy.Schema

var _IntegerEnum_C *smithy.Schema

var _IntegerEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumList",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumList_member *smithy.Schema

var _IntegerEnumMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumMap",
}, smithy.ShapeTypeMap, 2)
var _IntegerEnumMap_key *smithy.Schema

var _IntegerEnumMap_value *smithy.Schema

var _IntegerEnumSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumSet",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumSet_member *smithy.Schema

var _IntegerList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerList",
}, smithy.ShapeTypeList, 1)
var _IntegerList_member *smithy.Schema

var _IntegerSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerSet",
}, smithy.ShapeTypeList, 1)
var _IntegerSet_member *smithy.Schema

var _JpegBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "JpegBlob",
}, smithy.ShapeTypeBlob, 0, &smithytraits.MediaType{Type: "image/jpeg"})

var _NestedStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "NestedStringList",
}, smithy.ShapeTypeList, 1)
var _NestedStringList_member *smithy.Schema

var _SparseShortList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "SparseShortList",
}, smithy.ShapeTypeList, 1)
var _SparseShortList_member *smithy.Schema

var _SparseStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "SparseStringList",
}, smithy.ShapeTypeList, 1)
var _SparseStringList_member *smithy.Schema

var _SparseStringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "SparseStringMap",
}, smithy.ShapeTypeMap, 2)
var _SparseStringMap_key *smithy.Schema

var _SparseStringMap_value *smithy.Schema

var _StringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringList",
}, smithy.ShapeTypeList, 1)
var _StringList_member *smithy.Schema

var _StringListMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringListMap",
}, smithy.ShapeTypeMap, 2)
var _StringListMap_key *smithy.Schema

var _StringListMap_value *smithy.Schema

var _StringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringMap",
}, smithy.ShapeTypeMap, 2)
var _StringMap_key *smithy.Schema

var _StringMap_value *smithy.Schema

var _StringSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringSet",
}, smithy.ShapeTypeList, 1)
var _StringSet_member *smithy.Schema

var _TextPlainBlob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "TextPlainBlob",
}, smithy.ShapeTypeBlob, 0, &smithytraits.MediaType{Type: "text/plain"})

var _TimestampList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "TimestampList",
}, smithy.ShapeTypeList, 1)
var _TimestampList_member *smithy.Schema

var AllQueryStringTypesInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "AllQueryStringTypesInput",
}, smithy.ShapeTypeStructure, 21)
var AllQueryStringTypesInput_queryString *smithy.Schema

var AllQueryStringTypesInput_queryStringList *smithy.Schema

var AllQueryStringTypesInput_queryStringSet *smithy.Schema

var AllQueryStringTypesInput_queryByte *smithy.Schema

var AllQueryStringTypesInput_queryShort *smithy.Schema

var AllQueryStringTypesInput_queryInteger *smithy.Schema

var AllQueryStringTypesInput_queryIntegerList *smithy.Schema

var AllQueryStringTypesInput_queryIntegerSet *smithy.Schema

var AllQueryStringTypesInput_queryLong *smithy.Schema

var AllQueryStringTypesInput_queryFloat *smithy.Schema

var AllQueryStringTypesInput_queryDouble *smithy.Schema

var AllQueryStringTypesInput_queryDoubleList *smithy.Schema

var AllQueryStringTypesInput_queryBoolean *smithy.Schema

var AllQueryStringTypesInput_queryBooleanList *smithy.Schema

var AllQueryStringTypesInput_queryTimestamp *smithy.Schema

var AllQueryStringTypesInput_queryTimestampList *smithy.Schema

var AllQueryStringTypesInput_queryEnum *smithy.Schema

var AllQueryStringTypesInput_queryEnumList *smithy.Schema

var AllQueryStringTypesInput_queryIntegerEnum *smithy.Schema

var AllQueryStringTypesInput_queryIntegerEnumList *smithy.Schema

var AllQueryStringTypesInput_queryParamsMapOfStringList *smithy.Schema

var ConstantAndVariableQueryStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ConstantAndVariableQueryStringInput",
}, smithy.ShapeTypeStructure, 2)
var ConstantAndVariableQueryStringInput_baz *smithy.Schema

var ConstantAndVariableQueryStringInput_maybeSet *smithy.Schema

var ConstantQueryStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ConstantQueryStringInput",
}, smithy.ShapeTypeStructure, 1)
var ConstantQueryStringInput_hello *smithy.Schema

var ContentTypeParametersInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ContentTypeParametersInput",
}, smithy.ShapeTypeStructure, 1)
var ContentTypeParametersInput_value *smithy.Schema

var ContentTypeParametersOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ContentTypeParametersOutput",
}, smithy.ShapeTypeStructure, 0)

var DatetimeOffsetsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DatetimeOffsetsOutput",
}, smithy.ShapeTypeStructure, 1)
var DatetimeOffsetsOutput_datetime *smithy.Schema

var DocumentTypeAsMapValueInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentTypeAsMapValueInputOutput",
}, smithy.ShapeTypeStructure, 1)
var DocumentTypeAsMapValueInputOutput_docValuedMap *smithy.Schema

var DocumentTypeAsPayloadInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentTypeAsPayloadInputOutput",
}, smithy.ShapeTypeStructure, 1)
var DocumentTypeAsPayloadInputOutput_documentValue *smithy.Schema

var DocumentTypeInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DocumentTypeInputOutput",
}, smithy.ShapeTypeStructure, 2)
var DocumentTypeInputOutput_stringValue *smithy.Schema

var DocumentTypeInputOutput_documentValue *smithy.Schema

var DuplexStreamInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamInput",
}, smithy.ShapeTypeStructure, 1)
var DuplexStreamInput_stream *smithy.Schema

var DuplexStreamOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamOutput",
}, smithy.ShapeTypeStructure, 1)
var DuplexStreamOutput_stream *smithy.Schema

var DuplexStreamWithDistinctStreamsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamWithDistinctStreamsInput",
}, smithy.ShapeTypeStructure, 1)
var DuplexStreamWithDistinctStreamsInput_stream *smithy.Schema

var DuplexStreamWithDistinctStreamsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamWithDistinctStreamsOutput",
}, smithy.ShapeTypeStructure, 1)
var DuplexStreamWithDistinctStreamsOutput_stream *smithy.Schema

var DuplexStreamWithInitialMessagesInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamWithInitialMessagesInput",
}, smithy.ShapeTypeStructure, 2)
var DuplexStreamWithInitialMessagesInput_initialRequestMember *smithy.Schema

var DuplexStreamWithInitialMessagesInput_stream *smithy.Schema

var DuplexStreamWithInitialMessagesOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "DuplexStreamWithInitialMessagesOutput",
}, smithy.ShapeTypeStructure, 2)
var DuplexStreamWithInitialMessagesOutput_initialResponseMember *smithy.Schema

var DuplexStreamWithInitialMessagesOutput_stream *smithy.Schema

var EmptyInputAndEmptyOutputInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EmptyInputAndEmptyOutputInput",
}, smithy.ShapeTypeStructure, 0)

var EmptyInputAndEmptyOutputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EmptyInputAndEmptyOutputOutput",
}, smithy.ShapeTypeStructure, 0)

var HostLabelInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HostLabelInput",
}, smithy.ShapeTypeStructure, 1)
var HostLabelInput_label *smithy.Schema

var FractionalSecondsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "FractionalSecondsOutput",
}, smithy.ShapeTypeStructure, 1)
var FractionalSecondsOutput_datetime *smithy.Schema

var GreetingWithErrorsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "GreetingWithErrorsOutput",
}, smithy.ShapeTypeStructure, 1)
var GreetingWithErrorsOutput_greeting *smithy.Schema

var HttpChecksumRequiredInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpChecksumRequiredInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpChecksumRequiredInputOutput_foo *smithy.Schema

var HttpEmptyPrefixHeadersInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpEmptyPrefixHeadersInput",
}, smithy.ShapeTypeStructure, 2)
var HttpEmptyPrefixHeadersInput_prefixHeaders *smithy.Schema

var HttpEmptyPrefixHeadersInput_specificHeader *smithy.Schema

var HttpEmptyPrefixHeadersOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpEmptyPrefixHeadersOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpEmptyPrefixHeadersOutput_prefixHeaders *smithy.Schema

var HttpEmptyPrefixHeadersOutput_specificHeader *smithy.Schema

var EnumPayloadInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "EnumPayloadInput",
}, smithy.ShapeTypeStructure, 1)
var EnumPayloadInput_payload *smithy.Schema

var HttpPayloadTraitsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadTraitsInputOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpPayloadTraitsInputOutput_foo *smithy.Schema

var HttpPayloadTraitsInputOutput_blob *smithy.Schema

var HttpPayloadTraitsWithMediaTypeInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadTraitsWithMediaTypeInputOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpPayloadTraitsWithMediaTypeInputOutput_foo *smithy.Schema

var HttpPayloadTraitsWithMediaTypeInputOutput_blob *smithy.Schema

var HttpPayloadWithStructureInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadWithStructureInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithStructureInputOutput_nested *smithy.Schema

var HttpPayloadWithUnionInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPayloadWithUnionInputOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPayloadWithUnionInputOutput_nested *smithy.Schema

var HttpPrefixHeadersInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPrefixHeadersInput",
}, smithy.ShapeTypeStructure, 2)
var HttpPrefixHeadersInput_foo *smithy.Schema

var HttpPrefixHeadersInput_fooMap *smithy.Schema

var HttpPrefixHeadersInResponseInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPrefixHeadersInResponseInput",
}, smithy.ShapeTypeStructure, 0)

var HttpPrefixHeadersInResponseOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPrefixHeadersInResponseOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpPrefixHeadersInResponseOutput_prefixHeaders *smithy.Schema

var HttpPrefixHeadersOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpPrefixHeadersOutput",
}, smithy.ShapeTypeStructure, 2)
var HttpPrefixHeadersOutput_foo *smithy.Schema

var HttpPrefixHeadersOutput_fooMap *smithy.Schema

var HttpQueryParamsOnlyInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpQueryParamsOnlyInput",
}, smithy.ShapeTypeStructure, 1)
var HttpQueryParamsOnlyInput_queryMap *smithy.Schema

var HttpRequestWithFloatLabelsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithFloatLabelsInput",
}, smithy.ShapeTypeStructure, 2)
var HttpRequestWithFloatLabelsInput_float *smithy.Schema

var HttpRequestWithFloatLabelsInput_double *smithy.Schema

var HttpRequestWithGreedyLabelInPathInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithGreedyLabelInPathInput",
}, smithy.ShapeTypeStructure, 2)
var HttpRequestWithGreedyLabelInPathInput_foo *smithy.Schema

var HttpRequestWithGreedyLabelInPathInput_baz *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithLabelsAndTimestampFormatInput",
}, smithy.ShapeTypeStructure, 7)
var HttpRequestWithLabelsAndTimestampFormatInput_memberEpochSeconds *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_memberHttpDate *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_memberDateTime *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_defaultFormat *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_targetEpochSeconds *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_targetHttpDate *smithy.Schema

var HttpRequestWithLabelsAndTimestampFormatInput_targetDateTime *smithy.Schema

var HttpRequestWithLabelsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithLabelsInput",
}, smithy.ShapeTypeStructure, 8)
var HttpRequestWithLabelsInput_string *smithy.Schema

var HttpRequestWithLabelsInput_short *smithy.Schema

var HttpRequestWithLabelsInput_integer *smithy.Schema

var HttpRequestWithLabelsInput_long *smithy.Schema

var HttpRequestWithLabelsInput_float *smithy.Schema

var HttpRequestWithLabelsInput_double *smithy.Schema

var HttpRequestWithLabelsInput_boolean *smithy.Schema

var HttpRequestWithLabelsInput_timestamp *smithy.Schema

var HttpRequestWithRegexLiteralInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpRequestWithRegexLiteralInput",
}, smithy.ShapeTypeStructure, 1)
var HttpRequestWithRegexLiteralInput_str *smithy.Schema

var HttpResponseCodeOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "HttpResponseCodeOutput",
}, smithy.ShapeTypeStructure, 1)
var HttpResponseCodeOutput_Status *smithy.Schema

var StringPayloadInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StringPayloadInput",
}, smithy.ShapeTypeStructure, 1)
var StringPayloadInput_payload *smithy.Schema

var IgnoreQueryParamsInResponseOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "IgnoreQueryParamsInResponseOutput",
}, smithy.ShapeTypeStructure, 1)
var IgnoreQueryParamsInResponseOutput_baz *smithy.Schema

var InputAndOutputWithHeadersIO = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InputAndOutputWithHeadersIO",
}, smithy.ShapeTypeStructure, 18)
var InputAndOutputWithHeadersIO_headerString *smithy.Schema

var InputAndOutputWithHeadersIO_headerByte *smithy.Schema

var InputAndOutputWithHeadersIO_headerShort *smithy.Schema

var InputAndOutputWithHeadersIO_headerInteger *smithy.Schema

var InputAndOutputWithHeadersIO_headerLong *smithy.Schema

var InputAndOutputWithHeadersIO_headerFloat *smithy.Schema

var InputAndOutputWithHeadersIO_headerDouble *smithy.Schema

var InputAndOutputWithHeadersIO_headerTrueBool *smithy.Schema

var InputAndOutputWithHeadersIO_headerFalseBool *smithy.Schema

var InputAndOutputWithHeadersIO_headerStringList *smithy.Schema

var InputAndOutputWithHeadersIO_headerStringSet *smithy.Schema

var InputAndOutputWithHeadersIO_headerIntegerList *smithy.Schema

var InputAndOutputWithHeadersIO_headerBooleanList *smithy.Schema

var InputAndOutputWithHeadersIO_headerTimestampList *smithy.Schema

var InputAndOutputWithHeadersIO_headerEnum *smithy.Schema

var InputAndOutputWithHeadersIO_headerEnumList *smithy.Schema

var InputAndOutputWithHeadersIO_headerIntegerEnum *smithy.Schema

var InputAndOutputWithHeadersIO_headerIntegerEnumList *smithy.Schema

var InputStreamInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InputStreamInput",
}, smithy.ShapeTypeStructure, 1)
var InputStreamInput_stream *smithy.Schema

var InputStreamWithInitialRequestInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "InputStreamWithInitialRequestInput",
}, smithy.ShapeTypeStructure, 2)
var InputStreamWithInitialRequestInput_initialRequestMember *smithy.Schema

var InputStreamWithInitialRequestInput_stream *smithy.Schema

var JsonBlobsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonBlobsInputOutput",
}, smithy.ShapeTypeStructure, 1)
var JsonBlobsInputOutput_data *smithy.Schema

var JsonEnumsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonEnumsInputOutput",
}, smithy.ShapeTypeStructure, 6)
var JsonEnumsInputOutput_fooEnum1 *smithy.Schema

var JsonEnumsInputOutput_fooEnum2 *smithy.Schema

var JsonEnumsInputOutput_fooEnum3 *smithy.Schema

var JsonEnumsInputOutput_fooEnumList *smithy.Schema

var JsonEnumsInputOutput_fooEnumSet *smithy.Schema

var JsonEnumsInputOutput_fooEnumMap *smithy.Schema

var JsonIntEnumsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonIntEnumsInputOutput",
}, smithy.ShapeTypeStructure, 6)
var JsonIntEnumsInputOutput_integerEnum1 *smithy.Schema

var JsonIntEnumsInputOutput_integerEnum2 *smithy.Schema

var JsonIntEnumsInputOutput_integerEnum3 *smithy.Schema

var JsonIntEnumsInputOutput_integerEnumList *smithy.Schema

var JsonIntEnumsInputOutput_integerEnumSet *smithy.Schema

var JsonIntEnumsInputOutput_integerEnumMap *smithy.Schema

var JsonListsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonListsInputOutput",
}, smithy.ShapeTypeStructure, 9)
var JsonListsInputOutput_stringList *smithy.Schema

var JsonListsInputOutput_stringSet *smithy.Schema

var JsonListsInputOutput_integerList *smithy.Schema

var JsonListsInputOutput_booleanList *smithy.Schema

var JsonListsInputOutput_timestampList *smithy.Schema

var JsonListsInputOutput_enumList *smithy.Schema

var JsonListsInputOutput_intEnumList *smithy.Schema

var JsonListsInputOutput_nestedStringList *smithy.Schema

var JsonListsInputOutput_structureList *smithy.Schema

var JsonMapsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonMapsInputOutput",
}, smithy.ShapeTypeStructure, 5)
var JsonMapsInputOutput_denseStructMap *smithy.Schema

var JsonMapsInputOutput_denseNumberMap *smithy.Schema

var JsonMapsInputOutput_denseBooleanMap *smithy.Schema

var JsonMapsInputOutput_denseStringMap *smithy.Schema

var JsonMapsInputOutput_denseSetMap *smithy.Schema

var JsonTimestampsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "JsonTimestampsInputOutput",
}, smithy.ShapeTypeStructure, 7)
var JsonTimestampsInputOutput_normal *smithy.Schema

var JsonTimestampsInputOutput_dateTime *smithy.Schema

var JsonTimestampsInputOutput_dateTimeOnTarget *smithy.Schema

var JsonTimestampsInputOutput_epochSeconds *smithy.Schema

var JsonTimestampsInputOutput_epochSecondsOnTarget *smithy.Schema

var JsonTimestampsInputOutput_httpDate *smithy.Schema

var JsonTimestampsInputOutput_httpDateOnTarget *smithy.Schema

var UnionInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "UnionInputOutput",
}, smithy.ShapeTypeStructure, 1)
var UnionInputOutput_contents *smithy.Schema

var MalformedAcceptWithGenericStringOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedAcceptWithGenericStringOutput",
}, smithy.ShapeTypeStructure, 1)
var MalformedAcceptWithGenericStringOutput_payload *smithy.Schema

var MalformedAcceptWithPayloadOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedAcceptWithPayloadOutput",
}, smithy.ShapeTypeStructure, 1)
var MalformedAcceptWithPayloadOutput_payload *smithy.Schema

var MalformedBlobInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedBlobInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedBlobInput_blob *smithy.Schema

var MalformedBooleanInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedBooleanInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedBooleanInput_booleanInBody *smithy.Schema

var MalformedBooleanInput_booleanInPath *smithy.Schema

var MalformedBooleanInput_booleanInQuery *smithy.Schema

var MalformedBooleanInput_booleanInHeader *smithy.Schema

var MalformedByteInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedByteInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedByteInput_byteInBody *smithy.Schema

var MalformedByteInput_byteInPath *smithy.Schema

var MalformedByteInput_byteInQuery *smithy.Schema

var MalformedByteInput_byteInHeader *smithy.Schema

var MalformedContentTypeWithGenericStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithGenericStringInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedContentTypeWithGenericStringInput_payload *smithy.Schema

var MalformedContentTypeWithoutBodyEmptyInputInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithoutBodyEmptyInputInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedContentTypeWithoutBodyEmptyInputInput_header *smithy.Schema

var MalformedContentTypeWithPayloadInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedContentTypeWithPayloadInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedContentTypeWithPayloadInput_payload *smithy.Schema

var MalformedDoubleInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedDoubleInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedDoubleInput_doubleInBody *smithy.Schema

var MalformedDoubleInput_doubleInPath *smithy.Schema

var MalformedDoubleInput_doubleInQuery *smithy.Schema

var MalformedDoubleInput_doubleInHeader *smithy.Schema

var MalformedFloatInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedFloatInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedFloatInput_floatInBody *smithy.Schema

var MalformedFloatInput_floatInPath *smithy.Schema

var MalformedFloatInput_floatInQuery *smithy.Schema

var MalformedFloatInput_floatInHeader *smithy.Schema

var MalformedIntegerInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedIntegerInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedIntegerInput_integerInBody *smithy.Schema

var MalformedIntegerInput_integerInPath *smithy.Schema

var MalformedIntegerInput_integerInQuery *smithy.Schema

var MalformedIntegerInput_integerInHeader *smithy.Schema

var MalformedListInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedListInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedListInput_bodyList *smithy.Schema

var MalformedLongInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedLongInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedLongInput_longInBody *smithy.Schema

var MalformedLongInput_longInPath *smithy.Schema

var MalformedLongInput_longInQuery *smithy.Schema

var MalformedLongInput_longInHeader *smithy.Schema

var MalformedMapInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedMapInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedMapInput_bodyMap *smithy.Schema

var MalformedRequestBodyInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedRequestBodyInput",
}, smithy.ShapeTypeStructure, 2)
var MalformedRequestBodyInput_int *smithy.Schema

var MalformedRequestBodyInput_float *smithy.Schema

var MalformedShortInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedShortInput",
}, smithy.ShapeTypeStructure, 4)
var MalformedShortInput_shortInBody *smithy.Schema

var MalformedShortInput_shortInPath *smithy.Schema

var MalformedShortInput_shortInQuery *smithy.Schema

var MalformedShortInput_shortInHeader *smithy.Schema

var MalformedStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedStringInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedStringInput_blob *smithy.Schema

var MalformedTimestampBodyDateTimeInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampBodyDateTimeInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampBodyDateTimeInput_timestamp *smithy.Schema

var MalformedTimestampBodyDefaultInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampBodyDefaultInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampBodyDefaultInput_timestamp *smithy.Schema

var MalformedTimestampBodyHttpDateInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampBodyHttpDateInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampBodyHttpDateInput_timestamp *smithy.Schema

var MalformedTimestampHeaderDateTimeInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampHeaderDateTimeInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampHeaderDateTimeInput_timestamp *smithy.Schema

var MalformedTimestampHeaderDefaultInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampHeaderDefaultInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampHeaderDefaultInput_timestamp *smithy.Schema

var MalformedTimestampHeaderEpochInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampHeaderEpochInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampHeaderEpochInput_timestamp *smithy.Schema

var MalformedTimestampPathDefaultInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampPathDefaultInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampPathDefaultInput_timestamp *smithy.Schema

var MalformedTimestampPathEpochInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampPathEpochInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampPathEpochInput_timestamp *smithy.Schema

var MalformedTimestampPathHttpDateInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampPathHttpDateInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampPathHttpDateInput_timestamp *smithy.Schema

var MalformedTimestampQueryDefaultInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampQueryDefaultInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampQueryDefaultInput_timestamp *smithy.Schema

var MalformedTimestampQueryEpochInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampQueryEpochInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampQueryEpochInput_timestamp *smithy.Schema

var MalformedTimestampQueryHttpDateInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedTimestampQueryHttpDateInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedTimestampQueryHttpDateInput_timestamp *smithy.Schema

var MalformedUnionInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MalformedUnionInput",
}, smithy.ShapeTypeStructure, 1)
var MalformedUnionInput_union *smithy.Schema

var MediaTypeHeaderInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MediaTypeHeaderInput",
}, smithy.ShapeTypeStructure, 1)
var MediaTypeHeaderInput_json *smithy.Schema

var MediaTypeHeaderOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "MediaTypeHeaderOutput",
}, smithy.ShapeTypeStructure, 1)
var MediaTypeHeaderOutput_json *smithy.Schema

var NoInputAndOutputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NoInputAndOutputOutput",
}, smithy.ShapeTypeStructure, 0)

var NullAndEmptyHeadersIO = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "NullAndEmptyHeadersIO",
}, smithy.ShapeTypeStructure, 3)
var NullAndEmptyHeadersIO_a *smithy.Schema

var NullAndEmptyHeadersIO_b *smithy.Schema

var NullAndEmptyHeadersIO_c *smithy.Schema

var OmitsNullSerializesEmptyStringInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OmitsNullSerializesEmptyStringInput",
}, smithy.ShapeTypeStructure, 2)
var OmitsNullSerializesEmptyStringInput_nullValue *smithy.Schema

var OmitsNullSerializesEmptyStringInput_emptyString *smithy.Schema

var OmitsSerializingEmptyListsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OmitsSerializingEmptyListsInput",
}, smithy.ShapeTypeStructure, 7)
var OmitsSerializingEmptyListsInput_queryStringList *smithy.Schema

var OmitsSerializingEmptyListsInput_queryIntegerList *smithy.Schema

var OmitsSerializingEmptyListsInput_queryDoubleList *smithy.Schema

var OmitsSerializingEmptyListsInput_queryBooleanList *smithy.Schema

var OmitsSerializingEmptyListsInput_queryTimestampList *smithy.Schema

var OmitsSerializingEmptyListsInput_queryEnumList *smithy.Schema

var OmitsSerializingEmptyListsInput_queryIntegerEnumList *smithy.Schema

var OperationWithDefaultsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OperationWithDefaultsInput",
}, smithy.ShapeTypeStructure, 4)
var OperationWithDefaultsInput_defaults *smithy.Schema

var OperationWithDefaultsInput_clientOptionalDefaults *smithy.Schema

var OperationWithDefaultsInput_topLevelDefault *smithy.Schema

var OperationWithDefaultsInput_otherTopLevelDefault *smithy.Schema

var OperationWithDefaultsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OperationWithDefaultsOutput",
}, smithy.ShapeTypeStructure, 28)
var OperationWithDefaultsOutput_defaultString *smithy.Schema

var OperationWithDefaultsOutput_defaultBoolean *smithy.Schema

var OperationWithDefaultsOutput_defaultList *smithy.Schema

var OperationWithDefaultsOutput_defaultDocumentMap *smithy.Schema

var OperationWithDefaultsOutput_defaultDocumentString *smithy.Schema

var OperationWithDefaultsOutput_defaultDocumentBoolean *smithy.Schema

var OperationWithDefaultsOutput_defaultDocumentList *smithy.Schema

var OperationWithDefaultsOutput_defaultNullDocument *smithy.Schema

var OperationWithDefaultsOutput_defaultTimestamp *smithy.Schema

var OperationWithDefaultsOutput_defaultBlob *smithy.Schema

var OperationWithDefaultsOutput_defaultByte *smithy.Schema

var OperationWithDefaultsOutput_defaultShort *smithy.Schema

var OperationWithDefaultsOutput_defaultInteger *smithy.Schema

var OperationWithDefaultsOutput_defaultLong *smithy.Schema

var OperationWithDefaultsOutput_defaultFloat *smithy.Schema

var OperationWithDefaultsOutput_defaultDouble *smithy.Schema

var OperationWithDefaultsOutput_defaultMap *smithy.Schema

var OperationWithDefaultsOutput_defaultEnum *smithy.Schema

var OperationWithDefaultsOutput_defaultIntEnum *smithy.Schema

var OperationWithDefaultsOutput_emptyString *smithy.Schema

var OperationWithDefaultsOutput_falseBoolean *smithy.Schema

var OperationWithDefaultsOutput_emptyBlob *smithy.Schema

var OperationWithDefaultsOutput_zeroByte *smithy.Schema

var OperationWithDefaultsOutput_zeroShort *smithy.Schema

var OperationWithDefaultsOutput_zeroInteger *smithy.Schema

var OperationWithDefaultsOutput_zeroLong *smithy.Schema

var OperationWithDefaultsOutput_zeroFloat *smithy.Schema

var OperationWithDefaultsOutput_zeroDouble *smithy.Schema

var OperationWithNestedStructureInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OperationWithNestedStructureInput",
}, smithy.ShapeTypeStructure, 1)
var OperationWithNestedStructureInput_topLevel *smithy.Schema

var OperationWithNestedStructureOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OperationWithNestedStructureOutput",
}, smithy.ShapeTypeStructure, 3)
var OperationWithNestedStructureOutput_dialog *smithy.Schema

var OperationWithNestedStructureOutput_dialogList *smithy.Schema

var OperationWithNestedStructureOutput_dialogMap *smithy.Schema

var OutputStreamOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OutputStreamOutput",
}, smithy.ShapeTypeStructure, 1)
var OutputStreamOutput_stream *smithy.Schema

var OutputStreamWithInitialResponseOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "OutputStreamWithInitialResponseOutput",
}, smithy.ShapeTypeStructure, 2)
var OutputStreamWithInitialResponseOutput_initialResponseMember *smithy.Schema

var OutputStreamWithInitialResponseOutput_stream *smithy.Schema

var PostPlayerActionInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PostPlayerActionInput",
}, smithy.ShapeTypeStructure, 1)
var PostPlayerActionInput_action *smithy.Schema

var PostPlayerActionOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PostPlayerActionOutput",
}, smithy.ShapeTypeStructure, 1)
var PostPlayerActionOutput_action *smithy.Schema

var PostUnionWithJsonNameInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PostUnionWithJsonNameInput",
}, smithy.ShapeTypeStructure, 1)
var PostUnionWithJsonNameInput_value *smithy.Schema

var PostUnionWithJsonNameOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PostUnionWithJsonNameOutput",
}, smithy.ShapeTypeStructure, 1)
var PostUnionWithJsonNameOutput_value *smithy.Schema

var PutWithContentEncodingInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "PutWithContentEncodingInput",
}, smithy.ShapeTypeStructure, 2)
var PutWithContentEncodingInput_encoding *smithy.Schema

var PutWithContentEncodingInput_data *smithy.Schema

var QueryIdempotencyTokenAutoFillInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryIdempotencyTokenAutoFillInput",
}, smithy.ShapeTypeStructure, 1)
var QueryIdempotencyTokenAutoFillInput_token *smithy.Schema

var QueryParamsAsStringListMapInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryParamsAsStringListMapInput",
}, smithy.ShapeTypeStructure, 2)
var QueryParamsAsStringListMapInput_qux *smithy.Schema

var QueryParamsAsStringListMapInput_foo *smithy.Schema

var QueryPrecedenceInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "QueryPrecedenceInput",
}, smithy.ShapeTypeStructure, 2)
var QueryPrecedenceInput_foo *smithy.Schema

var QueryPrecedenceInput_baz *smithy.Schema

var RecursiveShapesInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "RecursiveShapesInputOutput",
}, smithy.ShapeTypeStructure, 1)
var RecursiveShapesInputOutput_nested *smithy.Schema

var ResponseCodeHttpFallbackInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ResponseCodeHttpFallbackInputOutput",
}, smithy.ShapeTypeStructure, 0)

var ResponseCodeRequiredOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "ResponseCodeRequiredOutput",
}, smithy.ShapeTypeStructure, 1)
var ResponseCodeRequiredOutput_responseCode *smithy.Schema

var SimpleScalarPropertiesInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SimpleScalarPropertiesInputOutput",
}, smithy.ShapeTypeStructure, 10)
var SimpleScalarPropertiesInputOutput_foo *smithy.Schema

var SimpleScalarPropertiesInputOutput_stringValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_trueBooleanValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_falseBooleanValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_byteValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_shortValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_integerValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_longValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_floatValue *smithy.Schema

var SimpleScalarPropertiesInputOutput_doubleValue *smithy.Schema

var SparseJsonListsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseJsonListsInputOutput",
}, smithy.ShapeTypeStructure, 2)
var SparseJsonListsInputOutput_sparseStringList *smithy.Schema

var SparseJsonListsInputOutput_sparseShortList *smithy.Schema

var SparseJsonMapsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "SparseJsonMapsInputOutput",
}, smithy.ShapeTypeStructure, 5)
var SparseJsonMapsInputOutput_sparseStructMap *smithy.Schema

var SparseJsonMapsInputOutput_sparseNumberMap *smithy.Schema

var SparseJsonMapsInputOutput_sparseBooleanMap *smithy.Schema

var SparseJsonMapsInputOutput_sparseStringMap *smithy.Schema

var SparseJsonMapsInputOutput_sparseSetMap *smithy.Schema

var StreamingTraitsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTraitsInputOutput",
}, smithy.ShapeTypeStructure, 2)
var StreamingTraitsInputOutput_foo *smithy.Schema

var StreamingTraitsInputOutput_blob *smithy.Schema

var StreamingTraitsRequireLengthInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTraitsRequireLengthInput",
}, smithy.ShapeTypeStructure, 2)
var StreamingTraitsRequireLengthInput_foo *smithy.Schema

var StreamingTraitsRequireLengthInput_blob *smithy.Schema

var StreamingTraitsWithMediaTypeInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "StreamingTraitsWithMediaTypeInputOutput",
}, smithy.ShapeTypeStructure, 2)
var StreamingTraitsWithMediaTypeInputOutput_foo *smithy.Schema

var StreamingTraitsWithMediaTypeInputOutput_blob *smithy.Schema

var TestBodyStructureInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestBodyStructureInputOutput",
}, smithy.ShapeTypeStructure, 2)
var TestBodyStructureInputOutput_testId *smithy.Schema

var TestBodyStructureInputOutput_testConfig *smithy.Schema

var TestNoPayloadInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestNoPayloadInputOutput",
}, smithy.ShapeTypeStructure, 1)
var TestNoPayloadInputOutput_testId *smithy.Schema

var TestPayloadBlobInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestPayloadBlobInputOutput",
}, smithy.ShapeTypeStructure, 2)
var TestPayloadBlobInputOutput_contentType *smithy.Schema

var TestPayloadBlobInputOutput_data *smithy.Schema

var TestPayloadStructureInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TestPayloadStructureInputOutput",
}, smithy.ShapeTypeStructure, 2)
var TestPayloadStructureInputOutput_testId *smithy.Schema

var TestPayloadStructureInputOutput_payloadConfig *smithy.Schema

var TimestampFormatHeadersIO = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.restjson",
	Name:      "TimestampFormatHeadersIO",
}, smithy.ShapeTypeStructure, 7)
var TimestampFormatHeadersIO_memberEpochSeconds *smithy.Schema

var TimestampFormatHeadersIO_memberHttpDate *smithy.Schema

var TimestampFormatHeadersIO_memberDateTime *smithy.Schema

var TimestampFormatHeadersIO_defaultFormat *smithy.Schema

var TimestampFormatHeadersIO_targetEpochSeconds *smithy.Schema

var TimestampFormatHeadersIO_targetHttpDate *smithy.Schema

var TimestampFormatHeadersIO_targetDateTime *smithy.Schema

// Initialize schema members after all schemas are declared to avoid
// initialization cycles
func init() {
	BlobPayloadEvent_payload = BlobPayloadEvent.AddMember("payload", smithyprelude.Blob, &smithytraits.EventPayload{})

	ClientOptionalDefaults_member = ClientOptionalDefaults.AddMember("member", smithyprelude.Integer)

	ComplexNestedErrorData_Foo = ComplexNestedErrorData.AddMember("Foo", smithyprelude.String, &smithytraits.JSONName{Name: "Fooooo"})

	ComplexError_Header = ComplexError.AddMember("Header", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Header"})

	ComplexError_TopLevel = ComplexError.AddMember("TopLevel", smithyprelude.String)

	ComplexError_Nested = ComplexError.AddMember("Nested", ComplexNestedErrorData)

	_TestStringList_member = _TestStringList.AddMember("member", smithyprelude.String)

	_TestStringMap_key = _TestStringMap.AddMember("key", smithyprelude.String)

	_TestStringMap_value = _TestStringMap.AddMember("value", smithyprelude.String)

	TestEnum_FOO = TestEnum.AddMember("FOO", smithyprelude.Unit)

	TestEnum_BAR = TestEnum.AddMember("BAR", smithyprelude.Unit)

	TestEnum_BAZ = TestEnum.AddMember("BAZ", smithyprelude.Unit)

	_TestIntEnum_ONE = _TestIntEnum.AddMember("ONE", smithyprelude.Unit)

	_TestIntEnum_TWO = _TestIntEnum.AddMember("TWO", smithyprelude.Unit)

	Defaults_defaultString = Defaults.AddMember("defaultString", smithyprelude.String)

	Defaults_defaultBoolean = Defaults.AddMember("defaultBoolean", smithyprelude.Boolean)

	Defaults_defaultList = Defaults.AddMember("defaultList", _TestStringList)

	Defaults_defaultDocumentMap = Defaults.AddMember("defaultDocumentMap", _Document)

	Defaults_defaultDocumentString = Defaults.AddMember("defaultDocumentString", _Document)

	Defaults_defaultDocumentBoolean = Defaults.AddMember("defaultDocumentBoolean", _Document)

	Defaults_defaultDocumentList = Defaults.AddMember("defaultDocumentList", _Document)

	Defaults_defaultNullDocument = Defaults.AddMember("defaultNullDocument", _Document)

	Defaults_defaultTimestamp = Defaults.AddMember("defaultTimestamp", smithyprelude.Timestamp)

	Defaults_defaultBlob = Defaults.AddMember("defaultBlob", smithyprelude.Blob)

	Defaults_defaultByte = Defaults.AddMember("defaultByte", smithyprelude.Byte)

	Defaults_defaultShort = Defaults.AddMember("defaultShort", smithyprelude.Short)

	Defaults_defaultInteger = Defaults.AddMember("defaultInteger", smithyprelude.Integer)

	Defaults_defaultLong = Defaults.AddMember("defaultLong", smithyprelude.Long)

	Defaults_defaultFloat = Defaults.AddMember("defaultFloat", smithyprelude.Float)

	Defaults_defaultDouble = Defaults.AddMember("defaultDouble", smithyprelude.Double)

	Defaults_defaultMap = Defaults.AddMember("defaultMap", _TestStringMap)

	Defaults_defaultEnum = Defaults.AddMember("defaultEnum", TestEnum)

	Defaults_defaultIntEnum = Defaults.AddMember("defaultIntEnum", _TestIntEnum)

	Defaults_emptyString = Defaults.AddMember("emptyString", smithyprelude.String)

	Defaults_falseBoolean = Defaults.AddMember("falseBoolean", smithyprelude.Boolean)

	Defaults_emptyBlob = Defaults.AddMember("emptyBlob", smithyprelude.Blob)

	Defaults_zeroByte = Defaults.AddMember("zeroByte", smithyprelude.Byte)

	Defaults_zeroShort = Defaults.AddMember("zeroShort", smithyprelude.Short)

	Defaults_zeroInteger = Defaults.AddMember("zeroInteger", smithyprelude.Integer)

	Defaults_zeroLong = Defaults.AddMember("zeroLong", smithyprelude.Long)

	Defaults_zeroFloat = Defaults.AddMember("zeroFloat", smithyprelude.Float)

	Defaults_zeroDouble = Defaults.AddMember("zeroDouble", smithyprelude.Double)

	_DenseBooleanMap_key = _DenseBooleanMap.AddMember("key", smithyprelude.String)

	_DenseBooleanMap_value = _DenseBooleanMap.AddMember("value", smithyprelude.Boolean)

	_DenseNumberMap_key = _DenseNumberMap.AddMember("key", smithyprelude.String)

	_DenseNumberMap_value = _DenseNumberMap.AddMember("value", smithyprelude.Integer)

	_StringSet_member = _StringSet.AddMember("member", smithyprelude.String)

	_DenseSetMap_key = _DenseSetMap.AddMember("key", smithyprelude.String)

	_DenseSetMap_value = _DenseSetMap.AddMember("value", _StringSet)

	_DenseStringMap_key = _DenseStringMap.AddMember("key", smithyprelude.String)

	_DenseStringMap_value = _DenseStringMap.AddMember("value", smithyprelude.String)

	GreetingStruct_hi = GreetingStruct.AddMember("hi", smithyprelude.String)

	_DenseStructMap_key = _DenseStructMap.AddMember("key", smithyprelude.String)

	_DenseStructMap_value = _DenseStructMap.AddMember("value", GreetingStruct)

	Farewell_phrase = Farewell.AddMember("phrase", smithyprelude.String)

	Dialog_language = Dialog.AddMember("language", smithyprelude.String)

	Dialog_greeting = Dialog.AddMember("greeting", smithyprelude.String)

	Dialog_farewell = Dialog.AddMember("farewell", Farewell)

	_DialogList_member = _DialogList.AddMember("member", Dialog)

	_DialogMap_key = _DialogMap.AddMember("key", smithyprelude.String)

	_DialogMap_value = _DialogMap.AddMember("value", Dialog)

	_DocumentValuedMap_key = _DocumentValuedMap.AddMember("key", smithyprelude.String)

	_DocumentValuedMap_value = _DocumentValuedMap.AddMember("value", _Document)

	ErrorEvent_message = ErrorEvent.AddMember("message", smithyprelude.String)

	HeadersEvent_booleanHeader = HeadersEvent.AddMember("booleanHeader", smithyprelude.Boolean, &smithytraits.EventHeader{})

	HeadersEvent_byteHeader = HeadersEvent.AddMember("byteHeader", smithyprelude.Byte, &smithytraits.EventHeader{})

	HeadersEvent_shortHeader = HeadersEvent.AddMember("shortHeader", smithyprelude.Short, &smithytraits.EventHeader{})

	HeadersEvent_intHeader = HeadersEvent.AddMember("intHeader", smithyprelude.Integer, &smithytraits.EventHeader{})

	HeadersEvent_longHeader = HeadersEvent.AddMember("longHeader", smithyprelude.Long, &smithytraits.EventHeader{})

	HeadersEvent_blobHeader = HeadersEvent.AddMember("blobHeader", smithyprelude.Blob, &smithytraits.EventHeader{})

	HeadersEvent_stringHeader = HeadersEvent.AddMember("stringHeader", smithyprelude.String, &smithytraits.EventHeader{})

	HeadersEvent_timestampHeader = HeadersEvent.AddMember("timestampHeader", _DateTime, &smithytraits.EventHeader{})

	StringPayloadEvent_payload = StringPayloadEvent.AddMember("payload", smithyprelude.String, &smithytraits.EventPayload{})

	PayloadStructure_structureMember = PayloadStructure.AddMember("structureMember", smithyprelude.String)

	StructurePayloadEvent_payload = StructurePayloadEvent.AddMember("payload", PayloadStructure, &smithytraits.EventPayload{})

	PayloadUnion_unionMember = PayloadUnion.AddMember("unionMember", smithyprelude.String)

	UnionPayloadEvent_payload = UnionPayloadEvent.AddMember("payload", PayloadUnion, &smithytraits.EventPayload{})

	HeadersAndExplicitPayloadEvent_header = HeadersAndExplicitPayloadEvent.AddMember("header", smithyprelude.String, &smithytraits.EventHeader{})

	HeadersAndExplicitPayloadEvent_payload = HeadersAndExplicitPayloadEvent.AddMember("payload", PayloadStructure, &smithytraits.EventPayload{})

	HeadersAndImplicitPayloadEvent_header = HeadersAndImplicitPayloadEvent.AddMember("header", smithyprelude.String, &smithytraits.EventHeader{})

	HeadersAndImplicitPayloadEvent_payload = HeadersAndImplicitPayloadEvent.AddMember("payload", smithyprelude.String)

	EventStream_headers = EventStream.AddMember("headers", HeadersEvent)

	EventStream_blobPayload = EventStream.AddMember("blobPayload", BlobPayloadEvent)

	EventStream_stringPayload = EventStream.AddMember("stringPayload", StringPayloadEvent)

	EventStream_structurePayload = EventStream.AddMember("structurePayload", StructurePayloadEvent)

	EventStream_unionPayload = EventStream.AddMember("unionPayload", UnionPayloadEvent)

	EventStream_headersAndExplicitPayload = EventStream.AddMember("headersAndExplicitPayload", HeadersAndExplicitPayloadEvent)

	EventStream_headersAndImplicitPayload = EventStream.AddMember("headersAndImplicitPayload", HeadersAndImplicitPayloadEvent)

	EventStream_error = EventStream.AddMember("error", ErrorEvent)

	InvalidGreeting_Message = InvalidGreeting.AddMember("Message", smithyprelude.String)

	FooEnum_FOO = FooEnum.AddMember("FOO", smithyprelude.Unit)

	FooEnum_BAZ = FooEnum.AddMember("BAZ", smithyprelude.Unit)

	FooEnum_BAR = FooEnum.AddMember("BAR", smithyprelude.Unit)

	FooEnum_ONE = FooEnum.AddMember("ONE", smithyprelude.Unit)

	FooEnum_ZERO = FooEnum.AddMember("ZERO", smithyprelude.Unit)

	_StringList_member = _StringList.AddMember("member", smithyprelude.String)

	_StringMap_key = _StringMap.AddMember("key", smithyprelude.String)

	_StringMap_value = _StringMap.AddMember("value", smithyprelude.String)

	RenamedGreeting_salutation = RenamedGreeting.AddMember("salutation", smithyprelude.String)

	MyUnion_stringValue = MyUnion.AddMember("stringValue", smithyprelude.String)

	MyUnion_booleanValue = MyUnion.AddMember("booleanValue", smithyprelude.Boolean)

	MyUnion_numberValue = MyUnion.AddMember("numberValue", smithyprelude.Integer)

	MyUnion_blobValue = MyUnion.AddMember("blobValue", smithyprelude.Blob)

	MyUnion_timestampValue = MyUnion.AddMember("timestampValue", smithyprelude.Timestamp)

	MyUnion_enumValue = MyUnion.AddMember("enumValue", FooEnum)

	MyUnion_listValue = MyUnion.AddMember("listValue", _StringList)

	MyUnion_mapValue = MyUnion.AddMember("mapValue", _StringMap)

	MyUnion_structureValue = MyUnion.AddMember("structureValue", GreetingStruct)

	MyUnion_renamedStructureValue = MyUnion.AddMember("renamedStructureValue", RenamedGreeting)

	NestedPayload_greeting = NestedPayload.AddMember("greeting", smithyprelude.String)

	NestedPayload_name = NestedPayload.AddMember("name", smithyprelude.String)

	PayloadConfig_data = PayloadConfig.AddMember("data", smithyprelude.Integer)

	PlayerAction_quit = PlayerAction.AddMember("quit", smithyprelude.Unit)

	_QueryMap_key = _QueryMap.AddMember("key", smithyprelude.String)

	_QueryMap_value = _QueryMap.AddMember("value", smithyprelude.String)

	RecursiveShapesInputOutputNested2_bar = RecursiveShapesInputOutputNested2.AddMember("bar", smithyprelude.String)

	RecursiveShapesInputOutputNested2_recursiveMember = RecursiveShapesInputOutputNested2.AddMember("recursiveMember", RecursiveShapesInputOutputNested1)

	RecursiveShapesInputOutputNested1_foo = RecursiveShapesInputOutputNested1.AddMember("foo", smithyprelude.String)

	RecursiveShapesInputOutputNested1_nested = RecursiveShapesInputOutputNested1.AddMember("nested", RecursiveShapesInputOutputNested2)

	ServiceUnavailableError_message = ServiceUnavailableError.AddMember("message", smithyprelude.String)

	_SimpleList_member = _SimpleList.AddMember("member", smithyprelude.String)

	_SimpleMap_key = _SimpleMap.AddMember("key", smithyprelude.String)

	_SimpleMap_value = _SimpleMap.AddMember("value", smithyprelude.String)

	SimpleUnion_int = SimpleUnion.AddMember("int", smithyprelude.Integer)

	SimpleUnion_string = SimpleUnion.AddMember("string", smithyprelude.String)

	SingletonEvent_value = SingletonEvent.AddMember("value", smithyprelude.String)

	SingletonEventStream_singleton = SingletonEventStream.AddMember("singleton", SingletonEvent)

	_SparseBooleanMap_key = _SparseBooleanMap.AddMember("key", smithyprelude.String)

	_SparseBooleanMap_value = _SparseBooleanMap.AddMember("value", smithyprelude.Boolean)

	_SparseNumberMap_key = _SparseNumberMap.AddMember("key", smithyprelude.String)

	_SparseNumberMap_value = _SparseNumberMap.AddMember("value", smithyprelude.Integer)

	_SparseSetMap_key = _SparseSetMap.AddMember("key", smithyprelude.String)

	_SparseSetMap_value = _SparseSetMap.AddMember("value", _StringSet)

	_SparseStructMap_key = _SparseStructMap.AddMember("key", smithyprelude.String)

	_SparseStructMap_value = _SparseStructMap.AddMember("value", GreetingStruct)

	StringEnum_V = StringEnum.AddMember("V", smithyprelude.Unit)

	StructureListMember_a = StructureListMember.AddMember("a", smithyprelude.String, &smithytraits.JSONName{Name: "value"})

	StructureListMember_b = StructureListMember.AddMember("b", smithyprelude.String, &smithytraits.JSONName{Name: "other"})

	_StructureList_member = _StructureList.AddMember("member", StructureListMember)

	TestConfig_timeout = TestConfig.AddMember("timeout", smithyprelude.Integer)

	TopLevel_dialog = TopLevel.AddMember("dialog", Dialog)

	TopLevel_dialogList = TopLevel.AddMember("dialogList", _DialogList)

	TopLevel_dialogMap = TopLevel.AddMember("dialogMap", _DialogMap)

	UnionPayload_greeting = UnionPayload.AddMember("greeting", smithyprelude.String)

	UnionWithJsonName_foo = UnionWithJsonName.AddMember("foo", smithyprelude.String, &smithytraits.JSONName{Name: "FOO"})

	UnionWithJsonName_bar = UnionWithJsonName.AddMember("bar", smithyprelude.String)

	UnionWithJsonName_baz = UnionWithJsonName.AddMember("baz", smithyprelude.String, &smithytraits.JSONName{Name: "_baz"})

	_BooleanList_member = _BooleanList.AddMember("member", smithyprelude.Boolean)

	_DoubleList_member = _DoubleList.AddMember("member", smithyprelude.Double)

	_FooEnumList_member = _FooEnumList.AddMember("member", FooEnum)

	_FooEnumMap_key = _FooEnumMap.AddMember("key", smithyprelude.String)

	_FooEnumMap_value = _FooEnumMap.AddMember("value", FooEnum)

	_FooEnumSet_member = _FooEnumSet.AddMember("member", FooEnum)

	_IntegerEnum_A = _IntegerEnum.AddMember("A", smithyprelude.Unit)

	_IntegerEnum_B = _IntegerEnum.AddMember("B", smithyprelude.Unit)

	_IntegerEnum_C = _IntegerEnum.AddMember("C", smithyprelude.Unit)

	_IntegerEnumList_member = _IntegerEnumList.AddMember("member", _IntegerEnum)

	_IntegerEnumMap_key = _IntegerEnumMap.AddMember("key", smithyprelude.String)

	_IntegerEnumMap_value = _IntegerEnumMap.AddMember("value", _IntegerEnum)

	_IntegerEnumSet_member = _IntegerEnumSet.AddMember("member", _IntegerEnum)

	_IntegerList_member = _IntegerList.AddMember("member", smithyprelude.Integer)

	_IntegerSet_member = _IntegerSet.AddMember("member", smithyprelude.Integer)

	_NestedStringList_member = _NestedStringList.AddMember("member", _StringList)

	_SparseShortList_member = _SparseShortList.AddMember("member", smithyprelude.Short)

	_SparseStringList_member = _SparseStringList.AddMember("member", smithyprelude.String)

	_SparseStringMap_key = _SparseStringMap.AddMember("key", smithyprelude.String)

	_SparseStringMap_value = _SparseStringMap.AddMember("value", smithyprelude.String)

	_StringListMap_key = _StringListMap.AddMember("key", smithyprelude.String)

	_StringListMap_value = _StringListMap.AddMember("value", _StringList)

	_TimestampList_member = _TimestampList.AddMember("member", smithyprelude.Timestamp)

	AllQueryStringTypesInput_queryString = AllQueryStringTypesInput.AddMember("queryString", smithyprelude.String, &smithytraits.HTTPQuery{Name: "String"})

	AllQueryStringTypesInput_queryStringList = AllQueryStringTypesInput.AddMember("queryStringList", _StringList, &smithytraits.HTTPQuery{Name: "StringList"})

	AllQueryStringTypesInput_queryStringSet = AllQueryStringTypesInput.AddMember("queryStringSet", _StringSet, &smithytraits.HTTPQuery{Name: "StringSet"})

	AllQueryStringTypesInput_queryByte = AllQueryStringTypesInput.AddMember("queryByte", smithyprelude.Byte, &smithytraits.HTTPQuery{Name: "Byte"})

	AllQueryStringTypesInput_queryShort = AllQueryStringTypesInput.AddMember("queryShort", smithyprelude.Short, &smithytraits.HTTPQuery{Name: "Short"})

	AllQueryStringTypesInput_queryInteger = AllQueryStringTypesInput.AddMember("queryInteger", smithyprelude.Integer, &smithytraits.HTTPQuery{Name: "Integer"})

	AllQueryStringTypesInput_queryIntegerList = AllQueryStringTypesInput.AddMember("queryIntegerList", _IntegerList, &smithytraits.HTTPQuery{Name: "IntegerList"})

	AllQueryStringTypesInput_queryIntegerSet = AllQueryStringTypesInput.AddMember("queryIntegerSet", _IntegerSet, &smithytraits.HTTPQuery{Name: "IntegerSet"})

	AllQueryStringTypesInput_queryLong = AllQueryStringTypesInput.AddMember("queryLong", smithyprelude.Long, &smithytraits.HTTPQuery{Name: "Long"})

	AllQueryStringTypesInput_queryFloat = AllQueryStringTypesInput.AddMember("queryFloat", smithyprelude.Float, &smithytraits.HTTPQuery{Name: "Float"})

	AllQueryStringTypesInput_queryDouble = AllQueryStringTypesInput.AddMember("queryDouble", smithyprelude.Double, &smithytraits.HTTPQuery{Name: "Double"})

	AllQueryStringTypesInput_queryDoubleList = AllQueryStringTypesInput.AddMember("queryDoubleList", _DoubleList, &smithytraits.HTTPQuery{Name: "DoubleList"})

	AllQueryStringTypesInput_queryBoolean = AllQueryStringTypesInput.AddMember("queryBoolean", smithyprelude.Boolean, &smithytraits.HTTPQuery{Name: "Boolean"})

	AllQueryStringTypesInput_queryBooleanList = AllQueryStringTypesInput.AddMember("queryBooleanList", _BooleanList, &smithytraits.HTTPQuery{Name: "BooleanList"})

	AllQueryStringTypesInput_queryTimestamp = AllQueryStringTypesInput.AddMember("queryTimestamp", smithyprelude.Timestamp, &smithytraits.HTTPQuery{Name: "Timestamp"})

	AllQueryStringTypesInput_queryTimestampList = AllQueryStringTypesInput.AddMember("queryTimestampList", _TimestampList, &smithytraits.HTTPQuery{Name: "TimestampList"})

	AllQueryStringTypesInput_queryEnum = AllQueryStringTypesInput.AddMember("queryEnum", FooEnum, &smithytraits.HTTPQuery{Name: "Enum"})

	AllQueryStringTypesInput_queryEnumList = AllQueryStringTypesInput.AddMember("queryEnumList", _FooEnumList, &smithytraits.HTTPQuery{Name: "EnumList"})

	AllQueryStringTypesInput_queryIntegerEnum = AllQueryStringTypesInput.AddMember("queryIntegerEnum", _IntegerEnum, &smithytraits.HTTPQuery{Name: "IntegerEnum"})

	AllQueryStringTypesInput_queryIntegerEnumList = AllQueryStringTypesInput.AddMember("queryIntegerEnumList", _IntegerEnumList, &smithytraits.HTTPQuery{Name: "IntegerEnumList"})

	AllQueryStringTypesInput_queryParamsMapOfStringList = AllQueryStringTypesInput.AddMember("queryParamsMapOfStringList", _StringListMap, &smithytraits.HTTPQueryParams{})

	ConstantAndVariableQueryStringInput_baz = ConstantAndVariableQueryStringInput.AddMember("baz", smithyprelude.String, &smithytraits.HTTPQuery{Name: "baz"})

	ConstantAndVariableQueryStringInput_maybeSet = ConstantAndVariableQueryStringInput.AddMember("maybeSet", smithyprelude.String, &smithytraits.HTTPQuery{Name: "maybeSet"})

	ConstantQueryStringInput_hello = ConstantQueryStringInput.AddMember("hello", smithyprelude.String, &smithytraits.HTTPLabel{})

	ContentTypeParametersInput_value = ContentTypeParametersInput.AddMember("value", smithyprelude.Integer)

	DatetimeOffsetsOutput_datetime = DatetimeOffsetsOutput.AddMember("datetime", _DateTime)

	DocumentTypeAsMapValueInputOutput_docValuedMap = DocumentTypeAsMapValueInputOutput.AddMember("docValuedMap", _DocumentValuedMap)

	DocumentTypeAsPayloadInputOutput_documentValue = DocumentTypeAsPayloadInputOutput.AddMember("documentValue", _Document, &smithytraits.HTTPPayload{})

	DocumentTypeInputOutput_stringValue = DocumentTypeInputOutput.AddMember("stringValue", smithyprelude.String)

	DocumentTypeInputOutput_documentValue = DocumentTypeInputOutput.AddMember("documentValue", _Document)

	DuplexStreamInput_stream = DuplexStreamInput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	DuplexStreamOutput_stream = DuplexStreamOutput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	DuplexStreamWithDistinctStreamsInput_stream = DuplexStreamWithDistinctStreamsInput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	DuplexStreamWithDistinctStreamsOutput_stream = DuplexStreamWithDistinctStreamsOutput.AddMember("stream", SingletonEventStream, &smithytraits.HTTPPayload{})

	DuplexStreamWithInitialMessagesInput_initialRequestMember = DuplexStreamWithInitialMessagesInput.AddMember("initialRequestMember", smithyprelude.String, &smithytraits.HTTPHeader{Name: "initial-request-member"})

	DuplexStreamWithInitialMessagesInput_stream = DuplexStreamWithInitialMessagesInput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	DuplexStreamWithInitialMessagesOutput_initialResponseMember = DuplexStreamWithInitialMessagesOutput.AddMember("initialResponseMember", smithyprelude.String, &smithytraits.HTTPHeader{Name: "initial-response-member"})

	DuplexStreamWithInitialMessagesOutput_stream = DuplexStreamWithInitialMessagesOutput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	HostLabelInput_label = HostLabelInput.AddMember("label", smithyprelude.String, &smithytraits.HostLabel{})

	FractionalSecondsOutput_datetime = FractionalSecondsOutput.AddMember("datetime", _DateTime)

	GreetingWithErrorsOutput_greeting = GreetingWithErrorsOutput.AddMember("greeting", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Greeting"})

	HttpChecksumRequiredInputOutput_foo = HttpChecksumRequiredInputOutput.AddMember("foo", smithyprelude.String)

	HttpEmptyPrefixHeadersInput_prefixHeaders = HttpEmptyPrefixHeadersInput.AddMember("prefixHeaders", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: ""})

	HttpEmptyPrefixHeadersInput_specificHeader = HttpEmptyPrefixHeadersInput.AddMember("specificHeader", smithyprelude.String, &smithytraits.HTTPHeader{Name: "hello"})

	HttpEmptyPrefixHeadersOutput_prefixHeaders = HttpEmptyPrefixHeadersOutput.AddMember("prefixHeaders", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: ""})

	HttpEmptyPrefixHeadersOutput_specificHeader = HttpEmptyPrefixHeadersOutput.AddMember("specificHeader", smithyprelude.String, &smithytraits.HTTPHeader{Name: "hello"})

	EnumPayloadInput_payload = EnumPayloadInput.AddMember("payload", StringEnum, &smithytraits.HTTPPayload{})

	HttpPayloadTraitsInputOutput_foo = HttpPayloadTraitsInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	HttpPayloadTraitsInputOutput_blob = HttpPayloadTraitsInputOutput.AddMember("blob", smithyprelude.Blob, &smithytraits.HTTPPayload{})

	HttpPayloadTraitsWithMediaTypeInputOutput_foo = HttpPayloadTraitsWithMediaTypeInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	HttpPayloadTraitsWithMediaTypeInputOutput_blob = HttpPayloadTraitsWithMediaTypeInputOutput.AddMember("blob", _TextPlainBlob, &smithytraits.HTTPPayload{})

	HttpPayloadWithStructureInputOutput_nested = HttpPayloadWithStructureInputOutput.AddMember("nested", NestedPayload, &smithytraits.HTTPPayload{})

	HttpPayloadWithUnionInputOutput_nested = HttpPayloadWithUnionInputOutput.AddMember("nested", UnionPayload, &smithytraits.HTTPPayload{})

	HttpPrefixHeadersInput_foo = HttpPrefixHeadersInput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "x-foo"})

	HttpPrefixHeadersInput_fooMap = HttpPrefixHeadersInput.AddMember("fooMap", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: "x-foo-"})

	HttpPrefixHeadersInResponseOutput_prefixHeaders = HttpPrefixHeadersInResponseOutput.AddMember("prefixHeaders", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: ""})

	HttpPrefixHeadersOutput_foo = HttpPrefixHeadersOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "x-foo"})

	HttpPrefixHeadersOutput_fooMap = HttpPrefixHeadersOutput.AddMember("fooMap", _StringMap, &smithytraits.HTTPPrefixHeaders{Prefix: "x-foo-"})

	HttpQueryParamsOnlyInput_queryMap = HttpQueryParamsOnlyInput.AddMember("queryMap", _QueryMap, &smithytraits.HTTPQueryParams{})

	HttpRequestWithFloatLabelsInput_float = HttpRequestWithFloatLabelsInput.AddMember("float", smithyprelude.Float, &smithytraits.HTTPLabel{})

	HttpRequestWithFloatLabelsInput_double = HttpRequestWithFloatLabelsInput.AddMember("double", smithyprelude.Double, &smithytraits.HTTPLabel{})

	HttpRequestWithGreedyLabelInPathInput_foo = HttpRequestWithGreedyLabelInPathInput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpRequestWithGreedyLabelInPathInput_baz = HttpRequestWithGreedyLabelInPathInput.AddMember("baz", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_memberEpochSeconds = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("memberEpochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},

		&smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_memberHttpDate = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("memberHttpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"},

		&smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_memberDateTime = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("memberDateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"},

		&smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_defaultFormat = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("defaultFormat", smithyprelude.Timestamp, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_targetEpochSeconds = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("targetEpochSeconds", _EpochSeconds, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_targetHttpDate = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("targetHttpDate", _HttpDate, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsAndTimestampFormatInput_targetDateTime = HttpRequestWithLabelsAndTimestampFormatInput.AddMember("targetDateTime", _DateTime, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_string = HttpRequestWithLabelsInput.AddMember("string", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_short = HttpRequestWithLabelsInput.AddMember("short", smithyprelude.Short, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_integer = HttpRequestWithLabelsInput.AddMember("integer", smithyprelude.Integer, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_long = HttpRequestWithLabelsInput.AddMember("long", smithyprelude.Long, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_float = HttpRequestWithLabelsInput.AddMember("float", smithyprelude.Float, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_double = HttpRequestWithLabelsInput.AddMember("double", smithyprelude.Double, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_boolean = HttpRequestWithLabelsInput.AddMember("boolean", smithyprelude.Boolean, &smithytraits.HTTPLabel{})

	HttpRequestWithLabelsInput_timestamp = HttpRequestWithLabelsInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.HTTPLabel{})

	HttpRequestWithRegexLiteralInput_str = HttpRequestWithRegexLiteralInput.AddMember("str", smithyprelude.String, &smithytraits.HTTPLabel{})

	HttpResponseCodeOutput_Status = HttpResponseCodeOutput.AddMember("Status", smithyprelude.Integer, &smithytraits.HTTPResponseCode{})

	StringPayloadInput_payload = StringPayloadInput.AddMember("payload", smithyprelude.String, &smithytraits.HTTPPayload{})

	IgnoreQueryParamsInResponseOutput_baz = IgnoreQueryParamsInResponseOutput.AddMember("baz", smithyprelude.String, &smithytraits.HTTPQuery{Name: "baz"})

	InputAndOutputWithHeadersIO_headerString = InputAndOutputWithHeadersIO.AddMember("headerString", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-String"})

	InputAndOutputWithHeadersIO_headerByte = InputAndOutputWithHeadersIO.AddMember("headerByte", smithyprelude.Byte, &smithytraits.HTTPHeader{Name: "X-Byte"})

	InputAndOutputWithHeadersIO_headerShort = InputAndOutputWithHeadersIO.AddMember("headerShort", smithyprelude.Short, &smithytraits.HTTPHeader{Name: "X-Short"})

	InputAndOutputWithHeadersIO_headerInteger = InputAndOutputWithHeadersIO.AddMember("headerInteger", smithyprelude.Integer, &smithytraits.HTTPHeader{Name: "X-Integer"})

	InputAndOutputWithHeadersIO_headerLong = InputAndOutputWithHeadersIO.AddMember("headerLong", smithyprelude.Long, &smithytraits.HTTPHeader{Name: "X-Long"})

	InputAndOutputWithHeadersIO_headerFloat = InputAndOutputWithHeadersIO.AddMember("headerFloat", smithyprelude.Float, &smithytraits.HTTPHeader{Name: "X-Float"})

	InputAndOutputWithHeadersIO_headerDouble = InputAndOutputWithHeadersIO.AddMember("headerDouble", smithyprelude.Double, &smithytraits.HTTPHeader{Name: "X-Double"})

	InputAndOutputWithHeadersIO_headerTrueBool = InputAndOutputWithHeadersIO.AddMember("headerTrueBool", smithyprelude.Boolean, &smithytraits.HTTPHeader{Name: "X-Boolean1"})

	InputAndOutputWithHeadersIO_headerFalseBool = InputAndOutputWithHeadersIO.AddMember("headerFalseBool", smithyprelude.Boolean, &smithytraits.HTTPHeader{Name: "X-Boolean2"})

	InputAndOutputWithHeadersIO_headerStringList = InputAndOutputWithHeadersIO.AddMember("headerStringList", _StringList, &smithytraits.HTTPHeader{Name: "X-StringList"})

	InputAndOutputWithHeadersIO_headerStringSet = InputAndOutputWithHeadersIO.AddMember("headerStringSet", _StringSet, &smithytraits.HTTPHeader{Name: "X-StringSet"})

	InputAndOutputWithHeadersIO_headerIntegerList = InputAndOutputWithHeadersIO.AddMember("headerIntegerList", _IntegerList, &smithytraits.HTTPHeader{Name: "X-IntegerList"})

	InputAndOutputWithHeadersIO_headerBooleanList = InputAndOutputWithHeadersIO.AddMember("headerBooleanList", _BooleanList, &smithytraits.HTTPHeader{Name: "X-BooleanList"})

	InputAndOutputWithHeadersIO_headerTimestampList = InputAndOutputWithHeadersIO.AddMember("headerTimestampList", _TimestampList, &smithytraits.HTTPHeader{Name: "X-TimestampList"})

	InputAndOutputWithHeadersIO_headerEnum = InputAndOutputWithHeadersIO.AddMember("headerEnum", FooEnum, &smithytraits.HTTPHeader{Name: "X-Enum"})

	InputAndOutputWithHeadersIO_headerEnumList = InputAndOutputWithHeadersIO.AddMember("headerEnumList", _FooEnumList, &smithytraits.HTTPHeader{Name: "X-EnumList"})

	InputAndOutputWithHeadersIO_headerIntegerEnum = InputAndOutputWithHeadersIO.AddMember("headerIntegerEnum", _IntegerEnum, &smithytraits.HTTPHeader{Name: "X-IntegerEnum"})

	InputAndOutputWithHeadersIO_headerIntegerEnumList = InputAndOutputWithHeadersIO.AddMember("headerIntegerEnumList", _IntegerEnumList, &smithytraits.HTTPHeader{Name: "X-IntegerEnumList"})

	InputStreamInput_stream = InputStreamInput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	InputStreamWithInitialRequestInput_initialRequestMember = InputStreamWithInitialRequestInput.AddMember("initialRequestMember", smithyprelude.String, &smithytraits.HTTPHeader{Name: "initial-request-member"})

	InputStreamWithInitialRequestInput_stream = InputStreamWithInitialRequestInput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	JsonBlobsInputOutput_data = JsonBlobsInputOutput.AddMember("data", smithyprelude.Blob)

	JsonEnumsInputOutput_fooEnum1 = JsonEnumsInputOutput.AddMember("fooEnum1", FooEnum)

	JsonEnumsInputOutput_fooEnum2 = JsonEnumsInputOutput.AddMember("fooEnum2", FooEnum)

	JsonEnumsInputOutput_fooEnum3 = JsonEnumsInputOutput.AddMember("fooEnum3", FooEnum)

	JsonEnumsInputOutput_fooEnumList = JsonEnumsInputOutput.AddMember("fooEnumList", _FooEnumList)

	JsonEnumsInputOutput_fooEnumSet = JsonEnumsInputOutput.AddMember("fooEnumSet", _FooEnumSet)

	JsonEnumsInputOutput_fooEnumMap = JsonEnumsInputOutput.AddMember("fooEnumMap", _FooEnumMap)

	JsonIntEnumsInputOutput_integerEnum1 = JsonIntEnumsInputOutput.AddMember("integerEnum1", _IntegerEnum)

	JsonIntEnumsInputOutput_integerEnum2 = JsonIntEnumsInputOutput.AddMember("integerEnum2", _IntegerEnum)

	JsonIntEnumsInputOutput_integerEnum3 = JsonIntEnumsInputOutput.AddMember("integerEnum3", _IntegerEnum)

	JsonIntEnumsInputOutput_integerEnumList = JsonIntEnumsInputOutput.AddMember("integerEnumList", _IntegerEnumList)

	JsonIntEnumsInputOutput_integerEnumSet = JsonIntEnumsInputOutput.AddMember("integerEnumSet", _IntegerEnumSet)

	JsonIntEnumsInputOutput_integerEnumMap = JsonIntEnumsInputOutput.AddMember("integerEnumMap", _IntegerEnumMap)

	JsonListsInputOutput_stringList = JsonListsInputOutput.AddMember("stringList", _StringList)

	JsonListsInputOutput_stringSet = JsonListsInputOutput.AddMember("stringSet", _StringSet)

	JsonListsInputOutput_integerList = JsonListsInputOutput.AddMember("integerList", _IntegerList)

	JsonListsInputOutput_booleanList = JsonListsInputOutput.AddMember("booleanList", _BooleanList)

	JsonListsInputOutput_timestampList = JsonListsInputOutput.AddMember("timestampList", _TimestampList)

	JsonListsInputOutput_enumList = JsonListsInputOutput.AddMember("enumList", _FooEnumList)

	JsonListsInputOutput_intEnumList = JsonListsInputOutput.AddMember("intEnumList", _IntegerEnumList)

	JsonListsInputOutput_nestedStringList = JsonListsInputOutput.AddMember("nestedStringList", _NestedStringList)

	JsonListsInputOutput_structureList = JsonListsInputOutput.AddMember("structureList", _StructureList, &smithytraits.JSONName{Name: "myStructureList"})

	JsonMapsInputOutput_denseStructMap = JsonMapsInputOutput.AddMember("denseStructMap", _DenseStructMap)

	JsonMapsInputOutput_denseNumberMap = JsonMapsInputOutput.AddMember("denseNumberMap", _DenseNumberMap)

	JsonMapsInputOutput_denseBooleanMap = JsonMapsInputOutput.AddMember("denseBooleanMap", _DenseBooleanMap)

	JsonMapsInputOutput_denseStringMap = JsonMapsInputOutput.AddMember("denseStringMap", _DenseStringMap)

	JsonMapsInputOutput_denseSetMap = JsonMapsInputOutput.AddMember("denseSetMap", _DenseSetMap)

	JsonTimestampsInputOutput_normal = JsonTimestampsInputOutput.AddMember("normal", smithyprelude.Timestamp)

	JsonTimestampsInputOutput_dateTime = JsonTimestampsInputOutput.AddMember("dateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"})

	JsonTimestampsInputOutput_dateTimeOnTarget = JsonTimestampsInputOutput.AddMember("dateTimeOnTarget", _DateTime)

	JsonTimestampsInputOutput_epochSeconds = JsonTimestampsInputOutput.AddMember("epochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

	JsonTimestampsInputOutput_epochSecondsOnTarget = JsonTimestampsInputOutput.AddMember("epochSecondsOnTarget", _EpochSeconds)

	JsonTimestampsInputOutput_httpDate = JsonTimestampsInputOutput.AddMember("httpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"})

	JsonTimestampsInputOutput_httpDateOnTarget = JsonTimestampsInputOutput.AddMember("httpDateOnTarget", _HttpDate)

	UnionInputOutput_contents = UnionInputOutput.AddMember("contents", MyUnion)

	MalformedAcceptWithGenericStringOutput_payload = MalformedAcceptWithGenericStringOutput.AddMember("payload", smithyprelude.String, &smithytraits.HTTPPayload{})

	MalformedAcceptWithPayloadOutput_payload = MalformedAcceptWithPayloadOutput.AddMember("payload", _JpegBlob, &smithytraits.HTTPPayload{})

	MalformedBlobInput_blob = MalformedBlobInput.AddMember("blob", smithyprelude.Blob)

	MalformedBooleanInput_booleanInBody = MalformedBooleanInput.AddMember("booleanInBody", smithyprelude.Boolean)

	MalformedBooleanInput_booleanInPath = MalformedBooleanInput.AddMember("booleanInPath", smithyprelude.Boolean, &smithytraits.HTTPLabel{})

	MalformedBooleanInput_booleanInQuery = MalformedBooleanInput.AddMember("booleanInQuery", smithyprelude.Boolean, &smithytraits.HTTPQuery{Name: "booleanInQuery"})

	MalformedBooleanInput_booleanInHeader = MalformedBooleanInput.AddMember("booleanInHeader", smithyprelude.Boolean, &smithytraits.HTTPHeader{Name: "booleanInHeader"})

	MalformedByteInput_byteInBody = MalformedByteInput.AddMember("byteInBody", smithyprelude.Byte)

	MalformedByteInput_byteInPath = MalformedByteInput.AddMember("byteInPath", smithyprelude.Byte, &smithytraits.HTTPLabel{})

	MalformedByteInput_byteInQuery = MalformedByteInput.AddMember("byteInQuery", smithyprelude.Byte, &smithytraits.HTTPQuery{Name: "byteInQuery"})

	MalformedByteInput_byteInHeader = MalformedByteInput.AddMember("byteInHeader", smithyprelude.Byte, &smithytraits.HTTPHeader{Name: "byteInHeader"})

	MalformedContentTypeWithGenericStringInput_payload = MalformedContentTypeWithGenericStringInput.AddMember("payload", smithyprelude.String, &smithytraits.HTTPPayload{})

	MalformedContentTypeWithoutBodyEmptyInputInput_header = MalformedContentTypeWithoutBodyEmptyInputInput.AddMember("header", smithyprelude.String, &smithytraits.HTTPHeader{Name: "header"})

	MalformedContentTypeWithPayloadInput_payload = MalformedContentTypeWithPayloadInput.AddMember("payload", _JpegBlob, &smithytraits.HTTPPayload{})

	MalformedDoubleInput_doubleInBody = MalformedDoubleInput.AddMember("doubleInBody", smithyprelude.Double)

	MalformedDoubleInput_doubleInPath = MalformedDoubleInput.AddMember("doubleInPath", smithyprelude.Double, &smithytraits.HTTPLabel{})

	MalformedDoubleInput_doubleInQuery = MalformedDoubleInput.AddMember("doubleInQuery", smithyprelude.Double, &smithytraits.HTTPQuery{Name: "doubleInQuery"})

	MalformedDoubleInput_doubleInHeader = MalformedDoubleInput.AddMember("doubleInHeader", smithyprelude.Double, &smithytraits.HTTPHeader{Name: "doubleInHeader"})

	MalformedFloatInput_floatInBody = MalformedFloatInput.AddMember("floatInBody", smithyprelude.Float)

	MalformedFloatInput_floatInPath = MalformedFloatInput.AddMember("floatInPath", smithyprelude.Float, &smithytraits.HTTPLabel{})

	MalformedFloatInput_floatInQuery = MalformedFloatInput.AddMember("floatInQuery", smithyprelude.Float, &smithytraits.HTTPQuery{Name: "floatInQuery"})

	MalformedFloatInput_floatInHeader = MalformedFloatInput.AddMember("floatInHeader", smithyprelude.Float, &smithytraits.HTTPHeader{Name: "floatInHeader"})

	MalformedIntegerInput_integerInBody = MalformedIntegerInput.AddMember("integerInBody", smithyprelude.Integer)

	MalformedIntegerInput_integerInPath = MalformedIntegerInput.AddMember("integerInPath", smithyprelude.Integer, &smithytraits.HTTPLabel{})

	MalformedIntegerInput_integerInQuery = MalformedIntegerInput.AddMember("integerInQuery", smithyprelude.Integer, &smithytraits.HTTPQuery{Name: "integerInQuery"})

	MalformedIntegerInput_integerInHeader = MalformedIntegerInput.AddMember("integerInHeader", smithyprelude.Integer, &smithytraits.HTTPHeader{Name: "integerInHeader"})

	MalformedListInput_bodyList = MalformedListInput.AddMember("bodyList", _SimpleList)

	MalformedLongInput_longInBody = MalformedLongInput.AddMember("longInBody", smithyprelude.Long)

	MalformedLongInput_longInPath = MalformedLongInput.AddMember("longInPath", smithyprelude.Long, &smithytraits.HTTPLabel{})

	MalformedLongInput_longInQuery = MalformedLongInput.AddMember("longInQuery", smithyprelude.Long, &smithytraits.HTTPQuery{Name: "longInQuery"})

	MalformedLongInput_longInHeader = MalformedLongInput.AddMember("longInHeader", smithyprelude.Long, &smithytraits.HTTPHeader{Name: "longInHeader"})

	MalformedMapInput_bodyMap = MalformedMapInput.AddMember("bodyMap", _SimpleMap)

	MalformedRequestBodyInput_int = MalformedRequestBodyInput.AddMember("int", smithyprelude.Integer)

	MalformedRequestBodyInput_float = MalformedRequestBodyInput.AddMember("float", smithyprelude.Float)

	MalformedShortInput_shortInBody = MalformedShortInput.AddMember("shortInBody", smithyprelude.Short)

	MalformedShortInput_shortInPath = MalformedShortInput.AddMember("shortInPath", smithyprelude.Short, &smithytraits.HTTPLabel{})

	MalformedShortInput_shortInQuery = MalformedShortInput.AddMember("shortInQuery", smithyprelude.Short, &smithytraits.HTTPQuery{Name: "shortInQuery"})

	MalformedShortInput_shortInHeader = MalformedShortInput.AddMember("shortInHeader", smithyprelude.Short, &smithytraits.HTTPHeader{Name: "shortInHeader"})

	MalformedStringInput_blob = MalformedStringInput.AddMember("blob", _JsonHeaderString, &smithytraits.HTTPHeader{Name: "amz-media-typed-header"})

	MalformedTimestampBodyDateTimeInput_timestamp = MalformedTimestampBodyDateTimeInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"})

	MalformedTimestampBodyDefaultInput_timestamp = MalformedTimestampBodyDefaultInput.AddMember("timestamp", smithyprelude.Timestamp)

	MalformedTimestampBodyHttpDateInput_timestamp = MalformedTimestampBodyHttpDateInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"})

	MalformedTimestampHeaderDateTimeInput_timestamp = MalformedTimestampHeaderDateTimeInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"},

		&smithytraits.HTTPHeader{Name: "timestamp"})

	MalformedTimestampHeaderDefaultInput_timestamp = MalformedTimestampHeaderDefaultInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.HTTPHeader{Name: "timestamp"})

	MalformedTimestampHeaderEpochInput_timestamp = MalformedTimestampHeaderEpochInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},

		&smithytraits.HTTPHeader{Name: "timestamp"})

	MalformedTimestampPathDefaultInput_timestamp = MalformedTimestampPathDefaultInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.HTTPLabel{})

	MalformedTimestampPathEpochInput_timestamp = MalformedTimestampPathEpochInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},

		&smithytraits.HTTPLabel{})

	MalformedTimestampPathHttpDateInput_timestamp = MalformedTimestampPathHttpDateInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"},

		&smithytraits.HTTPLabel{})

	MalformedTimestampQueryDefaultInput_timestamp = MalformedTimestampQueryDefaultInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.HTTPQuery{Name: "timestamp"})

	MalformedTimestampQueryEpochInput_timestamp = MalformedTimestampQueryEpochInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},

		&smithytraits.HTTPQuery{Name: "timestamp"})

	MalformedTimestampQueryHttpDateInput_timestamp = MalformedTimestampQueryHttpDateInput.AddMember("timestamp", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"},

		&smithytraits.HTTPQuery{Name: "timestamp"})

	MalformedUnionInput_union = MalformedUnionInput.AddMember("union", SimpleUnion)

	MediaTypeHeaderInput_json = MediaTypeHeaderInput.AddMember("json", _JsonValue, &smithytraits.HTTPHeader{Name: "X-Json"})

	MediaTypeHeaderOutput_json = MediaTypeHeaderOutput.AddMember("json", _JsonValue, &smithytraits.HTTPHeader{Name: "X-Json"})

	NullAndEmptyHeadersIO_a = NullAndEmptyHeadersIO.AddMember("a", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-A"})

	NullAndEmptyHeadersIO_b = NullAndEmptyHeadersIO.AddMember("b", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-B"})

	NullAndEmptyHeadersIO_c = NullAndEmptyHeadersIO.AddMember("c", _StringList, &smithytraits.HTTPHeader{Name: "X-C"})

	OmitsNullSerializesEmptyStringInput_nullValue = OmitsNullSerializesEmptyStringInput.AddMember("nullValue", smithyprelude.String, &smithytraits.HTTPQuery{Name: "Null"})

	OmitsNullSerializesEmptyStringInput_emptyString = OmitsNullSerializesEmptyStringInput.AddMember("emptyString", smithyprelude.String, &smithytraits.HTTPQuery{Name: "Empty"})

	OmitsSerializingEmptyListsInput_queryStringList = OmitsSerializingEmptyListsInput.AddMember("queryStringList", _StringList, &smithytraits.HTTPQuery{Name: "StringList"})

	OmitsSerializingEmptyListsInput_queryIntegerList = OmitsSerializingEmptyListsInput.AddMember("queryIntegerList", _IntegerList, &smithytraits.HTTPQuery{Name: "IntegerList"})

	OmitsSerializingEmptyListsInput_queryDoubleList = OmitsSerializingEmptyListsInput.AddMember("queryDoubleList", _DoubleList, &smithytraits.HTTPQuery{Name: "DoubleList"})

	OmitsSerializingEmptyListsInput_queryBooleanList = OmitsSerializingEmptyListsInput.AddMember("queryBooleanList", _BooleanList, &smithytraits.HTTPQuery{Name: "BooleanList"})

	OmitsSerializingEmptyListsInput_queryTimestampList = OmitsSerializingEmptyListsInput.AddMember("queryTimestampList", _TimestampList, &smithytraits.HTTPQuery{Name: "TimestampList"})

	OmitsSerializingEmptyListsInput_queryEnumList = OmitsSerializingEmptyListsInput.AddMember("queryEnumList", _FooEnumList, &smithytraits.HTTPQuery{Name: "EnumList"})

	OmitsSerializingEmptyListsInput_queryIntegerEnumList = OmitsSerializingEmptyListsInput.AddMember("queryIntegerEnumList", _IntegerEnumList, &smithytraits.HTTPQuery{Name: "IntegerEnumList"})

	OperationWithDefaultsInput_defaults = OperationWithDefaultsInput.AddMember("defaults", Defaults)

	OperationWithDefaultsInput_clientOptionalDefaults = OperationWithDefaultsInput.AddMember("clientOptionalDefaults", ClientOptionalDefaults)

	OperationWithDefaultsInput_topLevelDefault = OperationWithDefaultsInput.AddMember("topLevelDefault", smithyprelude.String)

	OperationWithDefaultsInput_otherTopLevelDefault = OperationWithDefaultsInput.AddMember("otherTopLevelDefault", smithyprelude.Integer)

	OperationWithDefaultsOutput_defaultString = OperationWithDefaultsOutput.AddMember("defaultString", smithyprelude.String)

	OperationWithDefaultsOutput_defaultBoolean = OperationWithDefaultsOutput.AddMember("defaultBoolean", smithyprelude.Boolean)

	OperationWithDefaultsOutput_defaultList = OperationWithDefaultsOutput.AddMember("defaultList", _TestStringList)

	OperationWithDefaultsOutput_defaultDocumentMap = OperationWithDefaultsOutput.AddMember("defaultDocumentMap", _Document)

	OperationWithDefaultsOutput_defaultDocumentString = OperationWithDefaultsOutput.AddMember("defaultDocumentString", _Document)

	OperationWithDefaultsOutput_defaultDocumentBoolean = OperationWithDefaultsOutput.AddMember("defaultDocumentBoolean", _Document)

	OperationWithDefaultsOutput_defaultDocumentList = OperationWithDefaultsOutput.AddMember("defaultDocumentList", _Document)

	OperationWithDefaultsOutput_defaultNullDocument = OperationWithDefaultsOutput.AddMember("defaultNullDocument", _Document)

	OperationWithDefaultsOutput_defaultTimestamp = OperationWithDefaultsOutput.AddMember("defaultTimestamp", smithyprelude.Timestamp)

	OperationWithDefaultsOutput_defaultBlob = OperationWithDefaultsOutput.AddMember("defaultBlob", smithyprelude.Blob)

	OperationWithDefaultsOutput_defaultByte = OperationWithDefaultsOutput.AddMember("defaultByte", smithyprelude.Byte)

	OperationWithDefaultsOutput_defaultShort = OperationWithDefaultsOutput.AddMember("defaultShort", smithyprelude.Short)

	OperationWithDefaultsOutput_defaultInteger = OperationWithDefaultsOutput.AddMember("defaultInteger", smithyprelude.Integer)

	OperationWithDefaultsOutput_defaultLong = OperationWithDefaultsOutput.AddMember("defaultLong", smithyprelude.Long)

	OperationWithDefaultsOutput_defaultFloat = OperationWithDefaultsOutput.AddMember("defaultFloat", smithyprelude.Float)

	OperationWithDefaultsOutput_defaultDouble = OperationWithDefaultsOutput.AddMember("defaultDouble", smithyprelude.Double)

	OperationWithDefaultsOutput_defaultMap = OperationWithDefaultsOutput.AddMember("defaultMap", _TestStringMap)

	OperationWithDefaultsOutput_defaultEnum = OperationWithDefaultsOutput.AddMember("defaultEnum", TestEnum)

	OperationWithDefaultsOutput_defaultIntEnum = OperationWithDefaultsOutput.AddMember("defaultIntEnum", _TestIntEnum)

	OperationWithDefaultsOutput_emptyString = OperationWithDefaultsOutput.AddMember("emptyString", smithyprelude.String)

	OperationWithDefaultsOutput_falseBoolean = OperationWithDefaultsOutput.AddMember("falseBoolean", smithyprelude.Boolean)

	OperationWithDefaultsOutput_emptyBlob = OperationWithDefaultsOutput.AddMember("emptyBlob", smithyprelude.Blob)

	OperationWithDefaultsOutput_zeroByte = OperationWithDefaultsOutput.AddMember("zeroByte", smithyprelude.Byte)

	OperationWithDefaultsOutput_zeroShort = OperationWithDefaultsOutput.AddMember("zeroShort", smithyprelude.Short)

	OperationWithDefaultsOutput_zeroInteger = OperationWithDefaultsOutput.AddMember("zeroInteger", smithyprelude.Integer)

	OperationWithDefaultsOutput_zeroLong = OperationWithDefaultsOutput.AddMember("zeroLong", smithyprelude.Long)

	OperationWithDefaultsOutput_zeroFloat = OperationWithDefaultsOutput.AddMember("zeroFloat", smithyprelude.Float)

	OperationWithDefaultsOutput_zeroDouble = OperationWithDefaultsOutput.AddMember("zeroDouble", smithyprelude.Double)

	OperationWithNestedStructureInput_topLevel = OperationWithNestedStructureInput.AddMember("topLevel", TopLevel)

	OperationWithNestedStructureOutput_dialog = OperationWithNestedStructureOutput.AddMember("dialog", Dialog)

	OperationWithNestedStructureOutput_dialogList = OperationWithNestedStructureOutput.AddMember("dialogList", _DialogList)

	OperationWithNestedStructureOutput_dialogMap = OperationWithNestedStructureOutput.AddMember("dialogMap", _DialogMap)

	OutputStreamOutput_stream = OutputStreamOutput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	OutputStreamWithInitialResponseOutput_initialResponseMember = OutputStreamWithInitialResponseOutput.AddMember("initialResponseMember", smithyprelude.String, &smithytraits.HTTPHeader{Name: "initial-response-member"})

	OutputStreamWithInitialResponseOutput_stream = OutputStreamWithInitialResponseOutput.AddMember("stream", EventStream, &smithytraits.HTTPPayload{})

	PostPlayerActionInput_action = PostPlayerActionInput.AddMember("action", PlayerAction)

	PostPlayerActionOutput_action = PostPlayerActionOutput.AddMember("action", PlayerAction)

	PostUnionWithJsonNameInput_value = PostUnionWithJsonNameInput.AddMember("value", UnionWithJsonName)

	PostUnionWithJsonNameOutput_value = PostUnionWithJsonNameOutput.AddMember("value", UnionWithJsonName)

	PutWithContentEncodingInput_encoding = PutWithContentEncodingInput.AddMember("encoding", smithyprelude.String, &smithytraits.HTTPHeader{Name: "Content-Encoding"})

	PutWithContentEncodingInput_data = PutWithContentEncodingInput.AddMember("data", smithyprelude.String)

	QueryIdempotencyTokenAutoFillInput_token = QueryIdempotencyTokenAutoFillInput.AddMember("token", smithyprelude.String, &smithytraits.HTTPQuery{Name: "token"})

	QueryParamsAsStringListMapInput_qux = QueryParamsAsStringListMapInput.AddMember("qux", smithyprelude.String, &smithytraits.HTTPQuery{Name: "corge"})

	QueryParamsAsStringListMapInput_foo = QueryParamsAsStringListMapInput.AddMember("foo", _StringListMap, &smithytraits.HTTPQueryParams{})

	QueryPrecedenceInput_foo = QueryPrecedenceInput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPQuery{Name: "bar"})

	QueryPrecedenceInput_baz = QueryPrecedenceInput.AddMember("baz", _StringMap, &smithytraits.HTTPQueryParams{})

	RecursiveShapesInputOutput_nested = RecursiveShapesInputOutput.AddMember("nested", RecursiveShapesInputOutputNested1)

	ResponseCodeRequiredOutput_responseCode = ResponseCodeRequiredOutput.AddMember("responseCode", smithyprelude.Integer, &smithytraits.HTTPResponseCode{})

	SimpleScalarPropertiesInputOutput_foo = SimpleScalarPropertiesInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	SimpleScalarPropertiesInputOutput_stringValue = SimpleScalarPropertiesInputOutput.AddMember("stringValue", smithyprelude.String)

	SimpleScalarPropertiesInputOutput_trueBooleanValue = SimpleScalarPropertiesInputOutput.AddMember("trueBooleanValue", smithyprelude.Boolean)

	SimpleScalarPropertiesInputOutput_falseBooleanValue = SimpleScalarPropertiesInputOutput.AddMember("falseBooleanValue", smithyprelude.Boolean)

	SimpleScalarPropertiesInputOutput_byteValue = SimpleScalarPropertiesInputOutput.AddMember("byteValue", smithyprelude.Byte)

	SimpleScalarPropertiesInputOutput_shortValue = SimpleScalarPropertiesInputOutput.AddMember("shortValue", smithyprelude.Short)

	SimpleScalarPropertiesInputOutput_integerValue = SimpleScalarPropertiesInputOutput.AddMember("integerValue", smithyprelude.Integer)

	SimpleScalarPropertiesInputOutput_longValue = SimpleScalarPropertiesInputOutput.AddMember("longValue", smithyprelude.Long)

	SimpleScalarPropertiesInputOutput_floatValue = SimpleScalarPropertiesInputOutput.AddMember("floatValue", smithyprelude.Float)

	SimpleScalarPropertiesInputOutput_doubleValue = SimpleScalarPropertiesInputOutput.AddMember("doubleValue", smithyprelude.Double, &smithytraits.JSONName{Name: "DoubleDribble"})

	SparseJsonListsInputOutput_sparseStringList = SparseJsonListsInputOutput.AddMember("sparseStringList", _SparseStringList)

	SparseJsonListsInputOutput_sparseShortList = SparseJsonListsInputOutput.AddMember("sparseShortList", _SparseShortList)

	SparseJsonMapsInputOutput_sparseStructMap = SparseJsonMapsInputOutput.AddMember("sparseStructMap", _SparseStructMap)

	SparseJsonMapsInputOutput_sparseNumberMap = SparseJsonMapsInputOutput.AddMember("sparseNumberMap", _SparseNumberMap)

	SparseJsonMapsInputOutput_sparseBooleanMap = SparseJsonMapsInputOutput.AddMember("sparseBooleanMap", _SparseBooleanMap)

	SparseJsonMapsInputOutput_sparseStringMap = SparseJsonMapsInputOutput.AddMember("sparseStringMap", _SparseStringMap)

	SparseJsonMapsInputOutput_sparseSetMap = SparseJsonMapsInputOutput.AddMember("sparseSetMap", _SparseSetMap)

	StreamingTraitsInputOutput_foo = StreamingTraitsInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	StreamingTraitsInputOutput_blob = StreamingTraitsInputOutput.AddMember("blob", _StreamingBlob, &smithytraits.HTTPPayload{})

	StreamingTraitsRequireLengthInput_foo = StreamingTraitsRequireLengthInput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	StreamingTraitsRequireLengthInput_blob = StreamingTraitsRequireLengthInput.AddMember("blob", _FiniteStreamingBlob, &smithytraits.HTTPPayload{})

	StreamingTraitsWithMediaTypeInputOutput_foo = StreamingTraitsWithMediaTypeInputOutput.AddMember("foo", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Foo"})

	StreamingTraitsWithMediaTypeInputOutput_blob = StreamingTraitsWithMediaTypeInputOutput.AddMember("blob", _StreamingTextPlainBlob, &smithytraits.HTTPPayload{})

	TestBodyStructureInputOutput_testId = TestBodyStructureInputOutput.AddMember("testId", smithyprelude.String, &smithytraits.HTTPHeader{Name: "x-amz-test-id"})

	TestBodyStructureInputOutput_testConfig = TestBodyStructureInputOutput.AddMember("testConfig", TestConfig)

	TestNoPayloadInputOutput_testId = TestNoPayloadInputOutput.AddMember("testId", smithyprelude.String, &smithytraits.HTTPHeader{Name: "X-Amz-Test-Id"})

	TestPayloadBlobInputOutput_contentType = TestPayloadBlobInputOutput.AddMember("contentType", smithyprelude.String, &smithytraits.HTTPHeader{Name: "Content-Type"})

	TestPayloadBlobInputOutput_data = TestPayloadBlobInputOutput.AddMember("data", smithyprelude.Blob, &smithytraits.HTTPPayload{})

	TestPayloadStructureInputOutput_testId = TestPayloadStructureInputOutput.AddMember("testId", smithyprelude.String, &smithytraits.HTTPHeader{Name: "x-amz-test-id"})

	TestPayloadStructureInputOutput_payloadConfig = TestPayloadStructureInputOutput.AddMember("payloadConfig", PayloadConfig, &smithytraits.HTTPPayload{})

	TimestampFormatHeadersIO_memberEpochSeconds = TimestampFormatHeadersIO.AddMember("memberEpochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"},
		&smithytraits.HTTPHeader{Name: "X-memberEpochSeconds"})

	TimestampFormatHeadersIO_memberHttpDate = TimestampFormatHeadersIO.AddMember("memberHttpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"},
		&smithytraits.HTTPHeader{Name: "X-memberHttpDate"})

	TimestampFormatHeadersIO_memberDateTime = TimestampFormatHeadersIO.AddMember("memberDateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"},
		&smithytraits.HTTPHeader{Name: "X-memberDateTime"})

	TimestampFormatHeadersIO_defaultFormat = TimestampFormatHeadersIO.AddMember("defaultFormat", smithyprelude.Timestamp, &smithytraits.HTTPHeader{Name: "X-defaultFormat"})

	TimestampFormatHeadersIO_targetEpochSeconds = TimestampFormatHeadersIO.AddMember("targetEpochSeconds", _EpochSeconds, &smithytraits.HTTPHeader{Name: "X-targetEpochSeconds"})

	TimestampFormatHeadersIO_targetHttpDate = TimestampFormatHeadersIO.AddMember("targetHttpDate", _HttpDate, &smithytraits.HTTPHeader{Name: "X-targetHttpDate"})

	TimestampFormatHeadersIO_targetDateTime = TimestampFormatHeadersIO.AddMember("targetDateTime", _DateTime, &smithytraits.HTTPHeader{Name: "X-targetDateTime"})

}
